@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
 
 import sys
 
+from collections import namedtuple
 from typing import Dict, List
 
 import click
@@ -29,13 +30,26 @@ from polyaxon.cli.operations import approve
 from polyaxon.cli.operations import logs as run_logs
 from polyaxon.cli.operations import statuses
 from polyaxon.cli.operations import upload as run_upload
+from polyaxon.cli.utils import handle_output
 from polyaxon.client import RunClient
+from polyaxon.constants.globals import DEFAULT_UPLOADS_PATH
+from polyaxon.constants.metadata import (
+    META_COPY_ARTIFACTS,
+    META_EAGER_MODE,
+    META_UPLOAD_ARTIFACTS,
+)
 from polyaxon.managers.run import RunConfigManager
 from polyaxon.polyflow import V1CompiledOperation, V1Operation
+from polyaxon.schemas import V1RunPending
+from polyaxon.schemas.types import V1ArtifactsType
 from polyaxon.utils import cache
 from polyaxon.utils.formatting import Printer
 
 
+class RunWatchSpec(namedtuple("RunWatchSpec", "uuid name")):
+    pass
+
+
 def run(
     ctx,
     name: str,
@@ -50,10 +64,8 @@ def run(
     upload_from: str,
     watch: bool,
     eager: bool,
+    output: str = None,
 ):
-    if eager and upload:
-        Printer.print_error("You can't use upload` and `eager` at the same.")
-        sys.exit(1)
 
     polyaxon_client = RunClient(owner=owner, project=project_name)
 
@@ -66,8 +78,9 @@ def run(
             project=project_name,
         )
 
-    def create_run(is_managed: bool = True, meta_info: Dict = None):
-        is_approved = False if upload else None
+    def create_run(
+        is_managed: bool = True, meta_info: Dict = None, pending: str = None
+    ):
         try:
             response = polyaxon_client.create(
                 name=name,
@@ -75,9 +88,14 @@ def run(
                 tags=tags,
                 content=op_spec,
                 is_managed=is_managed,
-                is_approved=is_approved,
                 meta_info=meta_info,
+                pending=pending,
             )
+            if output:
+                handle_output(
+                    polyaxon_client.client.sanitize_for_serialization(response), output
+                )
+                return
             Printer.print_success("A new run `{}` was created".format(response.uuid))
             if not eager:
                 cache_run(response)
@@ -90,7 +108,7 @@ def run(
                         )
                     )
                 )
-                return response.uuid
+            return response
         except (ApiException, HTTPError) as e:
             handle_cli_error(
                 e,
@@ -103,7 +121,7 @@ def run(
             )
             sys.exit(1)
 
-    def refresh():
+    def refresh_run():
         try:
             polyaxon_client.refresh_data()
         except (ApiException, HTTPError) as e:
@@ -112,36 +130,97 @@ def run(
             )
             sys.exit(1)
 
-    click.echo("Creating a new run...")
-    run_meta_info = {"eager": True} if eager or upload else None
-    run_uuid = create_run(not eager, run_meta_info)
-    if eager:
-        from polyaxon.polyaxonfile.manager import get_eager_matrix_operations
+    def delete_run():
+        try:
+            polyaxon_client.delete()
+        except (ApiException, HTTPError) as e:
+            handle_cli_error(
+                e, message="The current eager operation does not exist anymore."
+            )
+            sys.exit(1)
 
-        refresh()
-        click.echo("Starting eager mode...")
-        compiled_operation = V1CompiledOperation.read(polyaxon_client.run_data.content)
-        op_specs = get_eager_matrix_operations(
-            content=polyaxon_client.run_data.raw_content,
-            compiled_operation=compiled_operation,
-            is_cli=True,
-        )
-        click.echo("Creating {} operations".format(len(op_specs)))
-        for op_spec in op_specs:
-            create_run()
-        return
+    def watch_run_statuses(run_uuid: str):
+        ctx.obj = {"project": "{}/{}".format(owner, project_name), "run_uuid": run_uuid}
+        ctx.invoke(statuses, watch=True)
 
-    ctx.obj = {"project": "{}/{}".format(owner, project_name), "run_uuid": run_uuid}
-    if upload:
+    def watch_run_logs(run_uuid: str):
+        ctx.obj = {"project": "{}/{}".format(owner, project_name), "run_uuid": run_uuid}
+        ctx.invoke(run_logs)
+
+    def upload_run(run_uuid: str):
+        ctx.obj = {"project": "{}/{}".format(owner, project_name), "run_uuid": run_uuid}
         ctx.invoke(
             run_upload, path_to=upload_to, path_from=upload_from, sync_failure=True
         )
         ctx.invoke(approve)
 
+    if not output:
+        click.echo("Creating a new run...")
+    run_meta_info = None
+    if eager:
+        run_meta_info = {META_EAGER_MODE: True}
+    if upload:
+        run_meta_info = run_meta_info or {}
+        run_meta_info[META_UPLOAD_ARTIFACTS] = upload_to or DEFAULT_UPLOADS_PATH
+    run_instance = create_run(
+        not eager, run_meta_info, pending=V1RunPending.UPLOAD if upload else None
+    )
+    if not run_instance:
+        return
+
+    runs_to_watch = [RunWatchSpec(run_instance.uuid, run_instance.name)]
+
+    build_uuid = None
+    if run_instance.pending == V1RunPending.BUILD and run_instance.settings.build:
+        build_uuid = run_instance.settings.build.get("uuid")
+        build_name = run_instance.settings.build.get("name")
+        runs_to_watch.insert(0, RunWatchSpec(build_uuid, build_name))
+
+    if upload:
+        upload_run(build_uuid or run_instance.uuid)
+
+    if eager:
+        from polyaxon.polyaxonfile.manager import get_eager_matrix_operations
+
+        refresh_run()
+        # Prepare artifacts
+        run_meta_info = {}
+        if upload:
+            run_meta_info = {
+                META_UPLOAD_ARTIFACTS: upload_to or DEFAULT_UPLOADS_PATH,
+                META_COPY_ARTIFACTS: V1ArtifactsType(
+                    dirs=[run_instance.uuid]
+                ).to_dict(),
+            }
+        compiled_operation = V1CompiledOperation.read(polyaxon_client.run_data.content)
+        matrix_content = polyaxon_client.run_data.raw_content
+        # Delete matrix placeholder
+        click.echo("Cleaning matrix run placeholder...")
+        delete_run()
+        # Suggestions
+        click.echo("Starting eager mode...")
+        for op_spec in get_eager_matrix_operations(
+            content=matrix_content,
+            compiled_operation=compiled_operation,
+            is_cli=True,
+        ):
+            i_run_instance = create_run(meta_info=run_meta_info)
+            runs_to_watch.append(RunWatchSpec(i_run_instance.uuid, i_run_instance.name))
+
+        return
+
     # Check if we need to invoke logs
     if watch and not eager:
-        ctx.invoke(statuses, watch=True)
+        for instance in runs_to_watch:
+            Printer.print_success(
+                f"Starting watch for run: <Name: {instance.name}> - <uuid: {instance.uuid}>"
+            )
+            watch_run_statuses(instance.uuid)
 
     # Check if we need to invoke logs
     if log and not eager:
-        ctx.invoke(run_logs)
+        for instance in runs_to_watch:
+            Printer.print_success(
+                f"Starting logs for run: <Name: {instance.name}> - <uuid: {instance.uuid}>"
+            )
+            watch_run_logs(instance.uuid)
