@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,7 +13,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+import os
 import sys
 
 import click
@@ -24,9 +24,11 @@ from urllib3.exceptions import HTTPError
 from polyaxon.api import REWRITE_SERVICES_V1, SERVICES_V1
 from polyaxon.cli.dashboard import get_dashboard, get_dashboard_url
 from polyaxon.cli.errors import handle_cli_error
-from polyaxon.cli.options import OPTIONS_PROJECT, OPTIONS_RUN_UID
-from polyaxon.client import RunClient
-from polyaxon.client.run import get_run_logs
+from polyaxon.cli.options import OPTIONS_NAME, OPTIONS_PROJECT, OPTIONS_RUN_UID
+from polyaxon.cli.utils import handle_output
+from polyaxon.client import RunClient, get_run_logs
+from polyaxon.constants.metadata import META_REWRITE_PATH
+from polyaxon.containers import contexts as container_contexts
 from polyaxon.env_vars.getters import get_project_or_local, get_project_run_or_local
 from polyaxon.exceptions import (
     PolyaxonClientException,
@@ -35,9 +37,7 @@ from polyaxon.exceptions import (
 )
 from polyaxon.lifecycle import LifeCycle, V1Statuses
 from polyaxon.logger import clean_outputs
-from polyaxon.managers.ignore import IgnoreConfigManager
 from polyaxon.managers.run import RunConfigManager
-from polyaxon.metadata.keys import META_REWRITE_PATH
 from polyaxon.polyaxonfile import OperationSpecification
 from polyaxon.polyflow import V1RunKind
 from polyaxon.utils import cache
@@ -70,9 +70,25 @@ DEFAULT_EXCLUDE = [
     "pipeline",
     "role",
     "status_conditions",
+    "graph",
 ]
 
 
+def handle_run_statuses(status, conditions):
+    if not conditions:
+        return
+    Printer.print_header("Latest status:")
+    latest_status = Printer.add_status_color({"status": status}, status_key="status")
+    click.echo("{}\n".format(latest_status["status"]))
+
+    objects = list_dicts_to_tabulate(
+        [Printer.add_status_color(o.to_dict(), status_key="type") for o in conditions]
+    )
+    if objects:
+        Printer.print_header("Conditions:")
+        dict_tabulate(objects, is_list_dict=True)
+
+
 def get_run_details(run):  # pylint:disable=redefined-outer-name
     if run.description:
         Printer.print_header("Run description:")
@@ -99,7 +115,6 @@ def get_run_details(run):  # pylint:disable=redefined-outer-name
         response,
         humanize_values=True,
         exclude_attrs=[
-            "project",
             "description",
             "readme",
             "content",
@@ -110,6 +125,8 @@ def get_run_details(run):  # pylint:disable=redefined-outer-name
             "status_conditions",
             "settings",
             "meta_info",
+            "graph",
+            "merge",
         ],
     )
 
@@ -127,7 +144,7 @@ def ops(ctx, project, uid):
     ctx.obj = ctx.obj or {}
     if project or uid:
         Printer.print_warning(
-            "Passing arguments to command groups is deprecated and will be removed in v1.2! "
+            "Passing arguments to command groups is deprecated and will be removed in v2! "
             "Please use arguments on the sub-command directly: `polyaxon ops SUB_COMMAND --help`"
         )
     ctx.obj["project"] = project
@@ -157,9 +174,41 @@ def ops(ctx, project, uid):
 @click.option("--limit", "-l", type=int, help="To limit the list of runs.")
 @click.option("--offset", "-off", type=int, help="To offset the list of runs.")
 @click.option("--columns", "-c", type=str, help="The columns to show.")
+@click.option(
+    "--offline",
+    is_flag=True,
+    default=False,
+    help="To list offline runs if they exists.",
+)
+@click.option(
+    "--offline-path",
+    type=click.Path(exists=False),
+    help="Optional path to use to where offline runs are persisted, "
+    "default value is taken from the env var: `POLYAXON_OFFLINE_ROOT`.",
+)
+@click.option(
+    "--output",
+    "-o",
+    type=str,
+    help="Optional flag to print the results as a json object or store the results as json file"
+    "Example `-o json` or `-o path=./data.json`",
+)
 @click.pass_context
 @clean_outputs
-def ls(ctx, project, io, to_csv, query, sort, limit, offset, columns):
+def ls(
+    ctx,
+    project,
+    io,
+    to_csv,
+    query,
+    sort,
+    limit,
+    offset,
+    columns,
+    offline,
+    offline_path,
+    output,
+):
     """List runs for this project.
 
     Uses /docs/core/cli/#caching
@@ -195,32 +244,57 @@ def ls(ctx, project, io, to_csv, query, sort, limit, offset, columns):
     \b
     $ polyaxon ops ls -q "kind: service"
     """
-    owner, project_name = get_project_or_local(
-        project or ctx.obj.get("project"), is_cli=True
-    )
-
-    try:
-        polyaxon_client = RunClient(owner=owner, project=project_name)
-        response = polyaxon_client.list(
-            limit=limit, offset=offset, query=query, sort=sort
-        )
-    except (ApiException, HTTPError) as e:
-        handle_cli_error(
-            e, message="Could not get runs for project `{}`.".format(project_name)
-        )
-        sys.exit(1)
-
-    meta = get_meta_response(response)
-    if meta:
-        Printer.print_header("Runs for project `{}/{}`.".format(owner, project_name))
-        Printer.print_header("Navigation:")
-        dict_tabulate(meta)
+    if offline:
+        offline_path = offline_path or container_contexts.CONTEXT_OFFLINE_ROOT
+        offline_path_format = "{}/{{}}/run_data.json".format(offline_path)
+        if not os.path.exists(offline_path) or not os.path.isdir(offline_path):
+            Printer.print_error(
+                f"Could not list offline runs, the path `{offline_path}` "
+                f"does not exist or is not a directory."
+            )
+            sys.exit(1)
+        results = []
+        for uid in os.listdir(offline_path):
+            run_path = offline_path_format.format(uid)
+            if os.path.exists(run_path):
+                results.append(RunConfigManager.read_from_path(run_path))
+            else:
+                Printer.print_warning(f"Skipping run {uid}, offline data not found.")
     else:
-        Printer.print_header(
-            "No runs found for project `{}/{}`.".format(owner, project_name)
+        owner, project_name = get_project_or_local(
+            project or ctx.obj.get("project"), is_cli=True
         )
 
-    objects = [Printer.add_status_color(o.to_dict()) for o in response.results]
+        try:
+            polyaxon_client = RunClient(owner=owner, project=project_name)
+            response = polyaxon_client.list(
+                limit=limit, offset=offset, query=query, sort=sort
+            )
+        except (ApiException, HTTPError) as e:
+            handle_cli_error(
+                e, message="Could not get runs for project `{}`.".format(project_name)
+            )
+            sys.exit(1)
+
+        if output:
+            config = polyaxon_client.client.sanitize_for_serialization(response)
+            handle_output(config, output)
+            return
+        meta = get_meta_response(response)
+        if meta:
+            Printer.print_header(
+                "Runs for project `{}/{}`.".format(owner, project_name)
+            )
+            Printer.print_header("Navigation:")
+            dict_tabulate(meta)
+        else:
+            Printer.print_header(
+                "No runs found for project `{}/{}`.".format(owner, project_name)
+            )
+
+        results = response.results
+
+    objects = [Printer.add_status_color(o.to_dict()) for o in results]
     columns = validate_tags(columns)
     if io:
         objects, prefixed_columns = flatten_keys(
@@ -273,9 +347,28 @@ def ls(ctx, project, io, to_csv, query, sort, limit, offset, columns):
 @ops.command()
 @click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
 @click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
+@click.option(
+    "--offline",
+    is_flag=True,
+    default=False,
+    help="To list offline runs if they exists.",
+)
+@click.option(
+    "--offline-path",
+    type=click.Path(exists=False),
+    help="Optional path to use to where offline runs are persisted, "
+    "default value is taken from the env var: `POLYAXON_OFFLINE_ROOT`.",
+)
+@click.option(
+    "--output",
+    "-o",
+    type=str,
+    help="Optional flag to print the response as a json object or store the response as json file"
+    "Example `-o json` or `-o path=./data.json`",
+)
 @click.pass_context
 @clean_outputs
-def get(ctx, project, uid):
+def get(ctx, project, uid, offline, offline_path, output):
     """Get run.
 
     Uses /docs/core/cli/#caching
@@ -295,36 +388,53 @@ def get(ctx, project, uid):
     $ polyaxon ops get -p alain/cats-vs-dogs --uid=8aac02e3a62a4f0aaa257c59da5eab80
     """
 
-    owner, project_name, run_uuid = get_project_run_or_local(
-        project or ctx.obj.get("project"),
-        uid or ctx.obj.get("run_uuid"),
-        is_cli=True,
-    )
+    uid = uid or ctx.obj.get("run_uuid")
 
-    try:
-        polyaxon_client = RunClient(
-            owner=owner, project=project_name, run_uuid=run_uuid
+    if offline:
+        offline_path = offline_path or container_contexts.CONTEXT_OFFLINE_ROOT
+        offline_path = "{}/{}/run_data.json".format(offline_path, uid)
+        if not os.path.exists(offline_path):
+            Printer.print_error(
+                f"Could not get offline run, the path `{offline_path}` "
+                f"does not exist."
+            )
+            sys.exit(1)
+        run_data = RunConfigManager.read_from_path(offline_path)
+    else:
+        owner, project_name, run_uuid = get_project_run_or_local(
+            project or ctx.obj.get("project"),
+            uid,
+            is_cli=True,
         )
-        polyaxon_client.refresh_data()
-        config = polyaxon_client.client.sanitize_for_serialization(
-            polyaxon_client.run_data
-        )
-        cache.cache(
-            config_manager=RunConfigManager,
-            config=config,
-            owner=owner,
-            project=project_name,
-        )
-    except (ApiException, HTTPError) as e:
-        handle_cli_error(
-            e,
-            message="Could not load run `{}/{}/{}` info.".format(
-                owner, project_name, run_uuid
-            ),
-        )
-        sys.exit(1)
 
-    get_run_details(polyaxon_client.run_data)
+        try:
+            polyaxon_client = RunClient(
+                owner=owner, project=project_name, run_uuid=run_uuid
+            )
+            polyaxon_client.refresh_data()
+            config = polyaxon_client.client.sanitize_for_serialization(
+                polyaxon_client.run_data
+            )
+            cache.cache(
+                config_manager=RunConfigManager,
+                config=config,
+                owner=owner,
+                project=project_name,
+            )
+            if output:
+                handle_output(config, output)
+                return
+            run_data = polyaxon_client.run_data
+        except (ApiException, HTTPError) as e:
+            handle_cli_error(
+                e,
+                message="Could not load run `{}/{}/{}` info.".format(
+                    owner, project_name, run_uuid
+                ),
+            )
+            sys.exit(1)
+
+    get_run_details(run_data)
 
 
 @ops.command()
@@ -374,7 +484,7 @@ def delete(ctx, project, uid):
 @ops.command()
 @click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
 @click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
-@click.option("--name", type=str, help="Name of the run (optional).")
+@click.option(*OPTIONS_NAME["args"], type=str, help="Name of the run (optional).")
 @click.option("--description", type=str, help="Description of the run (optional).")
 @click.option(
     "--tags", type=str, help="Tags of the run, comma separated values (optional)."
@@ -406,7 +516,7 @@ def update(ctx, project, uid, name, description, tags):
     if name:
         update_dict["name"] = name
 
-    if description:
+    if description is not None:
         update_dict["description"] = description
 
     tags = validate_tags(tags)
@@ -463,7 +573,7 @@ def approve(ctx, project, uid):
         handle_cli_error(e, message="Could not approve run `{}`.".format(run_uuid))
         sys.exit(1)
 
-    Printer.print_success("Run is approved.")
+    Printer.print_success("Run is approved")
 
 
 @ops.command()
@@ -518,6 +628,13 @@ def stop(ctx, project, uid, yes):
 @ops.command()
 @click.option(*OPTIONS_PROJECT["args"], **OPTIONS_PROJECT["kwargs"])
 @click.option(*OPTIONS_RUN_UID["args"], **OPTIONS_RUN_UID["kwargs"])
+@click.option(
+    "--name",
+    type=str,
+    help="Name to give to this run, must be unique within the project, could be none.",
+)
+@click.option("--tags", type=str, help="Tags of this run, comma separated values.")
+@click.option("--description", type=str, help="The description to give to this run.")
 @click.option(
     "--copy",
     "-c",
@@ -525,6 +642,20 @@ def stop(ctx, project, uid, yes):
     default=False,
     help="To copy the run before restarting.",
 )
+@click.option(
+    "--copy-dir",
+    "copy_dirs",
+    multiple=True,
+    help="To copy specific dirs from the run's artifacts before restarting, "
+    "you can pass multiple dirs to copy `--copy-dir dir1 --copy-dir path/to/dir2`.",
+)
+@click.option(
+    "--copy-file",
+    "copy_files",
+    multiple=True,
+    help="To copy specific dirs from the run's artifacts before restarting, "
+    "you can pass multiple dirs to copy `--copy-file file1 --copy-file path/to/file2`.",
+)
 @click.option(
     "-f",
     "--file",
@@ -535,7 +666,18 @@ def stop(ctx, project, uid, yes):
 )
 @click.pass_context
 @clean_outputs
-def restart(ctx, project, uid, copy, polyaxonfile):
+def restart(
+    ctx,
+    project,
+    uid,
+    name,
+    tags,
+    description,
+    copy,
+    copy_dirs,
+    copy_files,
+    polyaxonfile,
+):
     """Restart run.
 
     Uses /docs/core/cli/#caching
@@ -560,7 +702,15 @@ def restart(ctx, project, uid, copy, polyaxonfile):
         polyaxon_client = RunClient(
             owner=owner, project=project_name, run_uuid=run_uuid
         )
-        response = polyaxon_client.restart(override_config=content, copy=copy)
+        response = polyaxon_client.restart(
+            name=name,
+            description=description,
+            tags=tags,
+            override_config=content,
+            copy=copy,
+            copy_dirs=copy_dirs,
+            copy_files=copy_files,
+        )
         Printer.print_success(
             "Run was {} with uid {}".format(
                 "copied" if copy else "restarted", response.uuid
@@ -655,7 +805,7 @@ def invalidate(ctx, project, uid):
 @click.pass_context
 @clean_outputs
 def statuses(ctx, project, uid, watch):
-    """Get run or run job statuses.
+    """Get run's statuses.
 
     Uses /docs/core/cli/#caching
 
@@ -668,25 +818,6 @@ def statuses(ctx, project, uid, watch):
     $ polyaxon ops statuses -uid=8aac02e3a62a4f0aaa257c59da5eab80
     """
 
-    def _handle_run_statuses():
-        if not conditions:
-            return
-        Printer.print_header("Latest status:")
-        latest_status = Printer.add_status_color(
-            {"status": status}, status_key="status"
-        )
-        click.echo("{}\n".format(latest_status["status"]))
-
-        objects = list_dicts_to_tabulate(
-            [
-                Printer.add_status_color(o.to_dict(), status_key="type")
-                for o in conditions
-            ]
-        )
-        if objects:
-            Printer.print_header("Conditions:")
-            dict_tabulate(objects, is_list_dict=True)
-
     owner, project_name, run_uuid = get_project_run_or_local(
         project or ctx.obj.get("project"),
         uid or ctx.obj.get("run_uuid"),
@@ -697,7 +828,7 @@ def statuses(ctx, project, uid, watch):
     if watch:
         try:
             for status, conditions in client.watch_statuses():
-                _handle_run_statuses()
+                handle_run_statuses(status, conditions)
         except (ApiException, HTTPError, PolyaxonClientException) as e:
             handle_cli_error(
                 e, message="Could get status for run `{}`.".format(run_uuid)
@@ -706,7 +837,7 @@ def statuses(ctx, project, uid, watch):
     else:
         try:
             status, conditions = client.get_statuses()
-            _handle_run_statuses()
+            handle_run_statuses(status, conditions)
         except (ApiException, HTTPError, PolyaxonClientException) as e:
             handle_cli_error(
                 e, message="Could get status for run `{}`.".format(run_uuid)
@@ -785,7 +916,7 @@ def statuses(ctx, project, uid, watch):
 @click.pass_context
 @clean_outputs
 def logs(ctx, project, uid, follow, hide_time, all_containers, all_info):
-    """Get run or run job logs.
+    """Get run's logs.
 
     Uses /docs/core/cli/#caching
 
@@ -882,12 +1013,17 @@ def artifacts(ctx, project, uid, path, path_to, no_untar):
 @click.option(
     "--path-from",
     type=click.Path(exists=False),
-    help="Path to use to upload. Defaults to current path.",
+    help="The path to upload from relative the current location (or absolute path), "
+    "Note that this must be a valid path, or the CLI will raise an error. "
+    "Defaults to the current path.",
 )
 @click.option(
     "--path-to",
     type=str,
-    help="The destination where to upload the artifacts. If run's root artifacts path will be used.",
+    help="The destination where to upload the artifacts. "
+    "If the path is '/' the root artifacts path of the run will be used, "
+    "otherwise the values should start without the separator, "
+    "e.g. `uploads`, `code`, `dataset/images/values`, ...",
 )
 @click.option(
     "--is-file",
@@ -899,7 +1035,7 @@ def artifacts(ctx, project, uid, path, path_to, no_untar):
     "--sync-failure",
     is_flag=True,
     default=False,
-    help="To set the run to failed if upload fails.",
+    help="To set the run to failed if the upload fails.",
 )
 @click.pass_context
 @clean_outputs
@@ -928,12 +1064,14 @@ def upload(ctx, project, uid, path_from, path_to, is_file, sync_failure):
         client = RunClient(owner=owner, project=project_name, run_uuid=run_uuid)
         if is_file:
             response = client.upload_artifact(
-                filepath=path_from, path=path_to or "", overwrite=True
+                filepath=path_from, path=path_to, overwrite=True
             )
         else:
-            files = IgnoreConfigManager.get_unignored_filepaths(path_from)
-            response = client.upload_artifacts(
-                files=files, path=path_to or "", overwrite=True, relative_to=path_from
+            response = client.upload_artifacts_dir(
+                dirpath=path_from,
+                path=path_to,
+                overwrite=True,
+                relative_to=path_from,
             )
     except (
         ApiException,
@@ -943,15 +1081,17 @@ def upload(ctx, project, uid, path_from, path_to, is_file, sync_failure):
         PolyaxonClientException,
     ) as e:
         handle_cli_error(
-            e, message="Could not upload artifacts for run `{}`.".format(run_uuid)
+            e, message="Could not upload artifacts for run `{}`".format(run_uuid)
         )
         sys.exit(1)
 
     if response.status_code == 200:
-        Printer.print_success("Artifacts uploaded.")
+        Printer.print_success("Artifacts uploaded")
     else:
         if sync_failure:
-            client.log_failed(message="Operation failed uploading artifacts.")
+            client.log_failed(
+                reason="OperationCli", message="Operation failed uploading artifacts"
+            )
         Printer.print_error(
             "Error uploading artifacts. "
             "Status: {}. Error: {}.".format(response.status_code, response.content),
@@ -1080,3 +1220,97 @@ def service(ctx, project, uid, yes, external, url):
         click.launch(external_run_url)
         sys.exit(0)
     click.launch(run_url)
+
+
+@ops.command()
+@click.option(
+    "--uid",
+    "-uid",
+    help="To single a single offline run using a its uuid.",
+)
+@click.option(
+    "--all-runs",
+    "-a",
+    is_flag=True,
+    default=False,
+    help="To sync all runs.",
+)
+@click.option(
+    "--no-artifacts",
+    is_flag=True,
+    default=False,
+    help="To disable uploading artifacts.",
+)
+@click.option(
+    "--clean",
+    "-c",
+    is_flag=True,
+    default=False,
+    help="To clean the run(s) local data after syncing.",
+)
+@click.option(
+    "--offline-path",
+    type=click.Path(exists=False),
+    help="Optional path to use to where offline runs are persisted, "
+    "default value is taken from the env var: `POLYAXON_OFFLINE_ROOT`.",
+)
+@clean_outputs
+def sync(uid, all_runs, no_artifacts, clean, offline_path):
+    """Syncs multiple offline runs or a single offline run if a uuid is passed.
+
+    Uses /docs/core/cli/#caching
+
+    Examples:
+
+    \b
+    $ polyaxon ops sync -a --clean
+
+    \b
+    $ polyaxon ops sync -uid=8aac02e3a62a4f0aaa257c59da5eab80 --clean
+
+    """
+    offline_path = offline_path or container_contexts.CONTEXT_OFFLINE_ROOT
+    offline_path_format = "{}/{{}}".format(offline_path)
+
+    def _sync(run_uuid: str):
+        Printer.print_header(f"Syncing offline run {uid} ...")
+        client = RunClient(run_uuid=run_uuid, is_offline=True)
+        try:
+            client.sync_offline_run(
+                load_offline_run=True,
+                artifacts_path=offline_path_format.format(run_uuid),
+                upload_artifacts=not no_artifacts,
+                clean=clean,
+            )
+        except (
+            ApiException,
+            HTTPError,
+            PolyaxonHTTPError,
+            PolyaxonShouldExitError,
+            PolyaxonClientException,
+        ) as e:
+            handle_cli_error(
+                e, message="Could not sync offline run `{}`.".format(run_uuid)
+            )
+            sys.exit(1)
+
+    if all_runs:
+        if (
+            not os.path.exists(offline_path)
+            or not os.path.isdir(offline_path)
+            or not os.listdir(offline_path)
+        ):
+            Printer.print_error(
+                f"Could not sync offline runs, the path `{offline_path}` "
+                f"does not exist, is not a directory, or is empty."
+            )
+            sys.exit(1)
+        for uid in os.listdir(offline_path):
+            _sync(uid)
+    elif uid:
+        _sync(uid)
+    else:
+        Printer.print_error(
+            "Please provide a run uuid or pass the flag `-a/--all` to sync runs."
+        )
+        sys.exit(1)
