@@ -26,21 +26,33 @@ from polyaxon.utils import indentation
 from polyaxon.utils.formatting import Printer, dict_tabulate, dict_to_tabulate
 from polyaxon.utils.versions import clean_version_for_check
 
-PROJECT_CLI_NAME = "polyaxon-cli"
+PROJECT_CLI_NAME = "polyaxon"
 
 
 def pip_upgrade(project_name=PROJECT_CLI_NAME):
     PipOperator.execute(["install", "--upgrade", project_name], stream=True)
-    click.echo("polyaxon-cli upgraded.")
+    click.echo("polyaxon upgraded.")
 
 
-def get_version(package):
+def get_version(package: str, show_error: bool = True):
     import pkg_resources
 
     try:
         return pkg_resources.get_distribution(package).version
     except pkg_resources.DistributionNotFound:
-        logger.error("`%s` is not installed", package)
+        if show_error:
+            logger.error("`%s` is not installed", package)
+
+
+def check_old_packages():
+    pkg = "polyaxon-cli"
+    if get_version(package=pkg, show_error=False):
+        Printer.print_error(
+            "Legacy package `{pkg}` is installed. Please run `pip uninstall {pkg}`".format(
+                pkg=pkg
+            ),
+            sys_exit=True,
+        )
 
 
 def get_current_version():
@@ -64,7 +76,7 @@ def check_cli_version(config, is_cli: bool = True):
             return
     if LooseVersion(current_version) < LooseVersion(min_version):
         click.echo(
-            """Your version of CLI ({}) is no longer compatible with server.""".format(
+            "Your version of Polyaxon CLI ({}) is no longer supported.".format(
                 config.current_version
             )
         )
@@ -74,17 +86,17 @@ def check_cli_version(config, is_cli: bool = True):
             pip_upgrade()
             sys.exit(0)
         else:
-            indentation.puts("Your can manually run:")
+            indentation.puts(
+                "To upgrade to the latest version `{}`, "
+                "you can manually run:".format(config.latest_version)
+            )
             with indentation.indent(4):
                 indentation.puts("pip install -U polyaxon")
-            indentation.puts(
-                "to upgrade to the latest version `{}`".format(config.latest_version)
-            )
 
             sys.exit(0)
     elif LooseVersion(current_version) < LooseVersion(latest_version):
         indentation.puts(
-            "New version of CLI ({}) is now available. To upgrade run:".format(
+            "New version of Polyaxon CLI ({}) is now available. To upgrade run:".format(
                 config.latest_version
             )
         )
@@ -93,7 +105,7 @@ def check_cli_version(config, is_cli: bool = True):
     elif LooseVersion(current_version) > LooseVersion(latest_version):
         indentation.puts(
             "Your version of CLI ({}) is ahead of the latest version "
-            "supported by Polyaxon Platform ({}) on your cluster, "
+            "supported by Polyaxon server ({}) on your cluster, "
             "and might be incompatible.".format(
                 config.current_version, config.latest_version
             )
@@ -107,6 +119,7 @@ def check_cli_version(config, is_cli: bool = True):
 @clean_outputs
 def version(check):
     """Print the current version of the cli and platform."""
+    check_old_packages()
     Printer.print_header("Current cli version: {}.".format(pkg.VERSION))
     if check:
         config = set_versions_config()
