@@ -53,7 +53,7 @@ from polyaxon.polyaxonfile import check_polyaxonfile
 from polyaxon.polyboard.artifacts import V1ArtifactKind, V1RunArtifact
 from polyaxon.polyboard.events import V1Events
 from polyaxon.polyboard.logging.streamer import get_logs_streamer
-from polyaxon.polyflow import V1Operation, V1RunKind
+from polyaxon.polyflow import V1Matrix, V1Operation, V1RunKind
 from polyaxon.schemas.types import V1ArtifactsType
 from polyaxon.stores.polyaxon_store import PolyaxonStore
 from polyaxon.utils.code_reference import get_code_reference
@@ -69,7 +69,6 @@ from polyaxon.utils.path_utils import (
     get_base_filename,
     get_dirs_under_path,
     get_files_in_path_context,
-    get_path,
 )
 from polyaxon.utils.query_params import get_logs_params, get_query_params
 from polyaxon.utils.tz_utils import now
@@ -156,12 +155,17 @@ class RunClient:
             if not self._is_offline
             else run_uuid or uuid.uuid4().hex
         )
+        default_runtime = (
+            V1RunKind.JOB
+            if self._is_offline or not settings.CLIENT_CONFIG.is_managed
+            else None
+        )
         self._run_data = polyaxon_sdk.V1Run(
             owner=self._owner,
             project=self._project,
             uuid=self._run_uuid,
-            kind=V1RunKind.JOB if self._is_offline else None,
-            runtime=V1RunKind.JOB if self._is_offline else None,
+            kind=default_runtime,
+            runtime=default_runtime,
             is_managed=False if self._is_offline else None,
         )
         self._namespace = None
@@ -368,10 +372,12 @@ class RunClient:
         description: str = None,
         tags: Union[str, Sequence[str]] = None,
         params: Dict = None,
+        matrix: Union[Dict, V1Matrix] = None,
         presets: List[str] = None,
         queue: str = None,
         nocache: bool = None,
-        cache: bool = None,
+        cache: Union[int, str, bool] = None,
+        approved: Union[int, str, bool] = None,
     ) -> V1Run:
         """Creates a new run based on a polyaxonfile.
 
@@ -393,18 +399,26 @@ class RunClient:
                  it will override the tags in the operation if provided.
             params: dict, optional, a dictionary of parameters that will be
                  used to resolve the component's inputs/outputs.
+            matrix: dict or V1Matrix, a matrix definition.
             presets: List[str], optional, the name of the
-                 [presets](/docs/core/scheduling-strategies/presets/).
+                 [presets](/docs/core/scheduling-presets/).
             queue: str, optional, the name of the
-                 [queue](/docs/core/scheduling-strategies/queue-routing/) to assign the run to.
-            nocache: bool, optional, simple flag to disable
+                 [queue](/docs/core/scheduling-strategies/queues/) to assign the run to.
+            nocache: bool, optional, DEPRECATED Please use `cache='f'`
+                 simple flag to disable
                  [cache check](/docs/automation/helpers/cache/).
                  If passed and the Polyaxonfile has cache section,
                  it will be patched with `disabled: true`.
-            cache: bool, optional, simple flag to enable
+            cache: Union[int, str, bool], optional, simple flag to enable/disable
                  [cache check](/docs/automation/helpers/cache/).
-                 If passed and the Polyaxonfile has cache section,
-                 it will be patched with `disabled: false`.
+                 If passed and the Polyaxonfile will be patched with `disabled: true/false`.
+                 e.g. `cache=1`, `cache='yes'`, `cache=False`, `cache='t'`, ...
+            approved: Union[int, str, bool], optional, simple flag to enable/disable
+                 human in the loop validation without changing the polyaxonfile,
+                 similar to `isApproved: true/false`,
+                 [manual approval](/docs/core/scheduling-strategies/manual-approval/).
+                 Can be used with yes/no, y/n, false/true, f/t, 1/0. "
+                 "e.g. `approved=1`, `approved='yes'`, `approved=False`, `approved='t'`, ..."
 
         Returns:
             V1Run, run instance from the response.
@@ -412,10 +426,12 @@ class RunClient:
         op_spec = check_polyaxonfile(
             polyaxonfile=polyaxonfile,
             params=params,
+            matrix=matrix,
             presets=presets,
             queue=queue,
             nocache=nocache,
             cache=cache,
+            approved=approved,
             verbose=False,
             is_cli=False,
         )
@@ -431,10 +447,12 @@ class RunClient:
         description: str = None,
         tags: Union[str, Sequence[str]] = None,
         params: Dict = None,
+        matrix: Union[Dict, V1Matrix] = None,
         presets: List[str] = None,
         queue: str = None,
         nocache: bool = None,
-        cache: bool = None,
+        cache: Union[int, str, bool] = None,
+        approved: Union[int, str, bool] = None,
     ) -> V1Run:
         """Creates a new run from a url containing a Polyaxonfile specification.
 
@@ -455,18 +473,26 @@ class RunClient:
                  it will override the tags in the operation if provided.
             params: dict, optional, a dictionary of parameters that will be
                  used to resolve the component's inputs/outputs.
+            matrix: dict or V1Matrix, a matrix definition.
             presets: List[str], optional, the name of the
-                 [presets](/docs/core/scheduling-strategies/presets/).
+                 [presets](/docs/core/scheduling-presets/).
             queue: str, optional, the name of the
-                 [queue](/docs/core/scheduling-strategies/queue-routing/) to assign the run to.
-            nocache: bool, optional, simple flag to disable
+                 [queue](/docs/core/scheduling-strategies/queues/) to assign the run to.
+            nocache: bool, optional, DEPRECATED Please use `cache='f'`
+                 simple flag to disable
                  [cache check](/docs/automation/helpers/cache/).
                  If passed and the Polyaxonfile has cache section,
                  it will be patched with `disabled: true`.
-            cache: bool, optional, simple flag to enable
+            cache: Union[int, str, bool], optional, simple flag to enable/disable
                  [cache check](/docs/automation/helpers/cache/).
-                 If passed and the Polyaxonfile has cache section,
-                 it will be patched with `disabled: false`.
+                 If passed and the Polyaxonfile will be patched with `disabled: true/false`.
+                 e.g. `cache=1`, `cache='yes'`, `cache=False`, `cache='t'`, ...
+            approved: Union[int, str, bool], optional, simple flag to enable/disable
+                 human in the loop validation without changing the polyaxonfile,
+                 similar to `isApproved: true/false`,
+                 [manual approval](/docs/core/scheduling-strategies/manual-approval/).
+                 Can be used with yes/no, y/n, false/true, f/t, 1/0. "
+                 "e.g. `approved=1`, `approved='yes'`, `approved=False`, `approved='t'`, ..."
 
         Returns:
             V1Run, run instance from the response.
@@ -474,10 +500,12 @@ class RunClient:
         op_spec = check_polyaxonfile(
             url=url,
             params=params,
+            matrix=matrix,
             presets=presets,
             queue=queue,
             nocache=nocache,
             cache=cache,
+            approved=approved,
             verbose=False,
             is_cli=False,
         )
@@ -493,10 +521,12 @@ class RunClient:
         description: str = None,
         tags: Union[str, Sequence[str]] = None,
         params: Dict = None,
+        matrix: Union[Dict, V1Matrix] = None,
         presets: str = None,
         queue: str = None,
         nocache: bool = None,
-        cache: bool = None,
+        cache: Union[int, str, bool] = None,
+        approved: Union[int, str, bool] = None,
     ) -> V1Run:
         """Creates a new run from the hub based on the component name.
 
@@ -516,18 +546,26 @@ class RunClient:
                  it will override the tags in the component if provided.
             params: dict, optional, a dictionary of parameters that will be
                  used to resolve the component's inputs/outputs.
+            matrix: dict or V1Matrix, a matrix definition.
             presets: List[str], optional, the name of the
-                 [presets](/docs/core/scheduling-strategies/presets/).
+                 [presets](/docs/core/scheduling-presets/).
             queue: str, optional, the name of the
-                 [queue](/docs/core/scheduling-strategies/queue-routing/) to assign the run to.
-            nocache: bool, optional, simple flag to disable
+                 [queue](/docs/core/scheduling-strategies/queues/) to assign the run to.
+            nocache: bool, optional, DEPRECATED Please use `cache='f'`
+                 simple flag to disable
                  [cache check](/docs/automation/helpers/cache/).
                  If passed and the Polyaxonfile has cache section,
                  it will be patched with `disabled: true`.
-            cache: bool, optional, simple flag to enable
+            cache: Union[int, str, bool], optional, simple flag to enable/disable
                  [cache check](/docs/automation/helpers/cache/).
-                 If passed and the Polyaxonfile has cache section,
-                 it will be patched with `disabled: false`.
+                 If passed and the Polyaxonfile will be patched with `disabled: true/false`.
+                 e.g. `cache=1`, `cache='yes'`, `cache=False`, `cache='t'`, ...
+            approved: Union[int, str, bool], optional, simple flag to enable/disable
+                 human in the loop validation without changing the polyaxonfile,
+                 similar to `isApproved: true/false`,
+                 [manual approval](/docs/core/scheduling-strategies/manual-approval/).
+                 Can be used with yes/no, y/n, false/true, f/t, 1/0. "
+                 "e.g. `approved=1`, `approved='yes'`, `approved=False`, `approved='t'`, ..."
 
         Returns:
             V1Run, run instance from the response.
@@ -535,10 +573,12 @@ class RunClient:
         op_spec = check_polyaxonfile(
             hub=component,
             params=params,
+            matrix=matrix,
             presets=presets,
             queue=queue,
             nocache=nocache,
             cache=cache,
+            approved=approved,
             verbose=False,
             is_cli=False,
         )
@@ -887,6 +927,7 @@ class RunClient:
         path: str = None,
         untar: bool = False,
         overwrite: bool = True,
+        show_progress: bool = True,
     ):
         """Uploads a single artifact to the run's artifacts store path.
 
@@ -896,6 +937,7 @@ class RunClient:
             untar: bool, optional, if the file uploaded is tar.gz and
                  it should be decompressed on the artifacts store.
             overwrite: bool, optional, if the file uploaded should overwrite any previous content.
+            show_progress: bool, to show a progress bar.
 
         Returns:
             str
@@ -915,6 +957,7 @@ class RunClient:
             path=path or "",
             untar=untar,
             overwrite=overwrite,
+            show_progress=show_progress,
         )
 
     @client_handler(check_no_op=True, check_offline=True)
@@ -991,7 +1034,7 @@ class RunClient:
         Args:
             path: str, the relative path of the artifact to return.
         """
-        return self.client.runs_v1.delete_run_artifact(
+        self.client.runs_v1.delete_run_artifact(
             namespace=self.namespace,
             owner=self.owner,
             project=self.project,
@@ -1687,9 +1730,9 @@ class RunClient:
 
         Args:
             query: str, optional, query filters, please refer to
-                 [Project PQL](/docs/core/query-language/runs/#query)
+                 [Run PQL](/docs/core/query-language/runs/#query)
             sort: str, optional, fields to order by, please refer to
-                 [Project PQL](/docs/core/query-language/runs/#sort)
+                 [Run PQL](/docs/core/query-language/runs/#sort)
             limit: int, optional, limit of runs to return.
             offset: int, optional, offset pages to paginate runs.
 
@@ -1728,13 +1771,14 @@ class RunClient:
 
         return self.client.runs_v1.list_runs(self.owner, self.project, **params)
 
-    def _sync_events_summaries(
+    def _collect_events_summaries(
         self,
         events_path: str,
         events_kind: str,
         last_check: Optional[datetime],
+        is_system_resource: bool = False,
     ) -> Tuple[List, Dict]:
-        current_events_path = get_path(events_path, events_kind)
+        current_events_path = os.path.join(events_path, events_kind)
 
         summaries = []
         last_values = {}
@@ -1756,7 +1800,7 @@ class RunClient:
                 summary = event.get_summary()
                 run_artifact = V1RunArtifact(
                     name=event_name,
-                    kind=events_kind,
+                    kind=V1ArtifactKind.SYSTEM if is_system_resource else events_kind,
                     connection=connection_name,
                     summary=summary,
                     path=event_rel_path,
@@ -1768,6 +1812,37 @@ class RunClient:
 
         return summaries, last_values
 
+    def _sync_events_summaries(
+        self,
+        last_check: Optional[datetime],
+        events_path: str,
+        is_system_resource: bool = False,
+    ):
+        # check if there's a path to sync
+        if not events_path or not os.path.exists(events_path):
+            return
+
+        # crawl dirs
+        summaries = []
+        last_values = {}
+        set_last_values = not is_system_resource
+
+        for events_kind in get_dirs_under_path(events_path):
+            _summaries, _last_values = self._collect_events_summaries(
+                events_path=events_path,
+                events_kind=events_kind,
+                last_check=last_check,
+                is_system_resource=is_system_resource,
+            )
+            summaries += _summaries
+            if set_last_values:
+                last_values.update(_last_values)
+
+        if summaries:
+            self.log_artifact_lineage(summaries)
+        if set_last_values and last_values:
+            self.log_outputs(**last_values)
+
     @client_handler(check_no_op=True)
     def sync_events_summaries(self, last_check: Optional[datetime], events_path: str):
         """Syncs all tracked events and auto-generates summaries and lineage data.
@@ -1775,27 +1850,26 @@ class RunClient:
         > **Note**: Both `in-cluster` and `offline` modes will manage syncing events summaries
         > automatically, so you should not call this method manually.
         """
-        # check if there's a path to sync
-        if not os.path.exists(events_path):
-            return
+        self._sync_events_summaries(
+            last_check=last_check,
+            events_path=events_path,
+            is_system_resource=False,
+        )
 
-        # crawl dirs
-        summaries = []
-        last_values = {}
+    @client_handler(check_no_op=True)
+    def sync_system_events_summaries(
+        self, last_check: Optional[datetime], events_path: str
+    ):
+        """Syncs all tracked system events and auto-generates summaries and lineage data.
 
-        for events_kind in get_dirs_under_path(events_path):
-            _summaries, _last_values = self._sync_events_summaries(
-                events_path=events_path,
-                events_kind=events_kind,
-                last_check=last_check,
-            )
-            summaries += _summaries
-            last_values.update(_last_values)
-
-        if summaries:
-            self.log_artifact_lineage(summaries)
-        if last_values:
-            self.log_outputs(**last_values)
+        > **Note**: Both `in-cluster` and `offline` modes will manage syncing events summaries
+        > automatically, so you should not call this method manually.
+        """
+        self._sync_events_summaries(
+            last_check=last_check,
+            events_path=events_path,
+            is_system_resource=True,
+        )
 
     @client_handler(check_no_op=True)
     def persist_offline_run(self, artifacts_path: str):
@@ -1810,7 +1884,7 @@ class RunClient:
                 "Make sure that the offline mode is enabled and that run_data is provided."
             )
             return
-        if not os.path.exists(artifacts_path):
+        if not artifacts_path or not os.path.exists(artifacts_path):
             check_or_create_path(artifacts_path, is_dir=True)
         run_path = "{}/run_data.json".format(artifacts_path)
         with open(run_path, "w") as config_file:
