@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -165,9 +165,10 @@ def _read_from_public_hub(hub: str):
 
 
 def _read_from_polyaxon_hub(hub: str):
-    from polyaxon.client import PolyaxonClient
-    from polyaxon.constants import DEFAULT_HUB, NO_AUTH
+    from polyaxon.client import PolyaxonClient, ProjectClient
+    from polyaxon.constants.globals import DEFAULT_HUB, NO_AUTH
     from polyaxon.env_vars.getters import get_component_info
+    from polyaxon.lifecycle import V1ProjectVersionKind
     from polyaxon.schemas.cli.client_config import ClientConfig
 
     owner, component, version = get_component_info(hub)
@@ -181,7 +182,10 @@ def _read_from_polyaxon_hub(hub: str):
             )
         else:
             client = PolyaxonClient()
-        response = client.component_hub_v1.get_component_version(owner, component, version)
+        client = ProjectClient(owner=owner, project=component, client=client)
+        response = client.get_version(
+            kind=V1ProjectVersionKind.COMPONENT, version=version
+        )
         return _read_from_stream(response.content)
     except (ApiException, HTTPError) as e:
         raise PolyaxonClientException(
@@ -249,7 +253,7 @@ def _read_from_python(f_path, f_module):
 
 def _read_from_file(f_path, file_type):
     _, ext = os.path.splitext(f_path)
-    if ext in (".yml", ".yaml") or file_type in (".yml", ".yaml"):
+    if ext in (".yml", ".yaml") or file_type in (None, ".yml", ".yaml"):
         return _read_from_yml(f_path)
     elif ext == ".json" or file_type == ".json":
         return _read_from_json(f_path)
