@@ -19,6 +19,8 @@ INIT_AUTH_CONTAINER = "polyaxon-init-auth"
 SIDECAR_CONTAINER = "polyaxon-sidecar"
 TFJOBS_CONTAINER = "tensorflow"
 PYTORCHJOBS_CONTAINER = "pytorch"
+MXJOBS_CONTAINER = "mxnet"
+XGBJOBS_CONTAINER = "xgboost"
 INIT_DOCKERFILE_CONTAINER_PREFIX = "polyaxon-init-dockerfile"
 INIT_FILE_CONTAINER_PREFIX = "polyaxon-init-file"
 INIT_GIT_CONTAINER_PREFIX = "polyaxon-init-git"
@@ -35,10 +37,11 @@ def generate_container_name(
     import uuid
 
     prefix = prefix or "container"
-    unique_prefix = uuid.uuid4().hex[:10]
+    unique_value = uuid.uuid4().hex[:10]
     if suffix:
+        suffix = suffix.replace("_", "-")
         if unique:
-            suffix = "{}-{}".format(suffix, unique_prefix)
+            suffix = "{}-{}".format(suffix, unique_value)
     else:
-        suffix = unique_prefix
+        suffix = unique_value
     return "{}-{}".format(prefix, suffix)
