@@ -16,6 +16,13 @@
 
 from marshmallow import ValidationError, fields, validate, validates_schema
 
+from polyaxon.auxiliaries import (
+    PolyaxonCleanerSchema,
+    PolyaxonInitContainerSchema,
+    PolyaxonNotifierSchema,
+    PolyaxonSidecarContainerSchema,
+)
+from polyaxon.auxiliaries.default_scheduling import DefaultSchedulingSchema
 from polyaxon.deploy.schemas.auth import AuthSchema
 from polyaxon.deploy.schemas.deployment_types import DeploymentCharts, DeploymentTypes
 from polyaxon.deploy.schemas.email import EmailSchema
@@ -28,14 +35,13 @@ from polyaxon.deploy.schemas.security_context import SecurityContextSchema
 from polyaxon.deploy.schemas.service import (
     AgentServiceSchema,
     ApiServiceSchema,
+    DeploymentServiceSchema,
     ExternalServicesSchema,
-    HelperServiceSchema,
     HooksSchema,
     OperatorServiceSchema,
     PostgresqlSchema,
     RabbitmqSchema,
     RedisSchema,
-    ServiceSchema,
     WorkerServiceSchema,
 )
 from polyaxon.deploy.schemas.service_types import ServiceTypes
@@ -79,7 +85,7 @@ def check_postgres(postgresql, external_services):
 def check_rabbitmq(rabbitmq, external_services, broker):
     rabbitmq_enabled = rabbitmq and rabbitmq.enabled
     external_rabbitmq = None
-    rabbitmq_borker = broker != "redis"
+    rabbitmq_broker = broker != "redis"
     if external_services:
         external_rabbitmq = external_services.rabbitmq
 
@@ -89,7 +95,7 @@ def check_rabbitmq(rabbitmq, external_services, broker):
             "not both!"
         )
     rabbitmq_used = rabbitmq_enabled or external_rabbitmq
-    if rabbitmq_used and not rabbitmq_borker:
+    if rabbitmq_used and not rabbitmq_broker:
         raise ValidationError(
             "rabbitmq is enabled but you are using a different broker backend!"
         )
@@ -202,7 +208,6 @@ class DeploymentSchema(BaseCamelSchema):
     deployment_chart = fields.Str(
         allow_none=True,
         validate=validate.OneOf(DeploymentCharts.VALUES),
-        default=DeploymentCharts.PLATFORM,
     )
     deployment_version = fields.Str(allow_none=True)
     release_name = fields.Str(allow_none=True)
@@ -222,6 +227,9 @@ class DeploymentSchema(BaseCamelSchema):
     node_selector = fields.Dict(allow_none=True)
     tolerations = fields.List(fields.Dict(allow_none=True), allow_none=True)
     affinity = fields.Dict(allow_none=True)
+    celery_node_selector = fields.Dict(allow_none=True)
+    celery_tolerations = fields.List(fields.Dict(allow_none=True), allow_none=True)
+    celery_affinity = fields.Dict(allow_none=True)
     limit_resources = fields.Bool(allow_none=True)
     global_replicas = fields.Int(allow_none=True)
     global_concurrency = fields.Int(allow_none=True)
@@ -231,16 +239,20 @@ class DeploymentSchema(BaseCamelSchema):
     scheduler = fields.Nested(WorkerServiceSchema, allow_none=True)
     compiler = fields.Nested(WorkerServiceSchema, allow_none=True)
     worker = fields.Nested(WorkerServiceSchema, allow_none=True)
-    beat = fields.Nested(ServiceSchema, allow_none=True)
+    beat = fields.Nested(DeploymentServiceSchema, allow_none=True)
     agent = fields.Nested(AgentServiceSchema, allow_none=True)
     operator = fields.Nested(OperatorServiceSchema, allow_none=True)
-    init = fields.Nested(HelperServiceSchema, allow_none=True)
-    sidecar = fields.Nested(HelperServiceSchema, allow_none=True)
-    tables_hook = fields.Nested(ServiceSchema, allow_none=True)
-    clean_hooks = fields.Nested(ServiceSchema, allow_none=True)
-    api_hooks = fields.Nested(ServiceSchema, allow_none=True)
+    init = fields.Nested(PolyaxonInitContainerSchema, allow_none=True)
+    sidecar = fields.Nested(PolyaxonSidecarContainerSchema, allow_none=True)
+    notifier = fields.Nested(PolyaxonNotifierSchema, allow_none=True)
+    cleaner = fields.Nested(PolyaxonCleanerSchema, allow_none=True)
+    default_scheduling = fields.Nested(DefaultSchedulingSchema, allow_none=True)
+    default_image_pull_secrets = fields.List(fields.Str(), allow_none=True)
+    tables_hook = fields.Nested(HooksSchema, allow_none=True)
+    clean_hooks = fields.Nested(HooksSchema, allow_none=True)
+    api_hooks = fields.Nested(HooksSchema, allow_none=True)
     hooks = fields.Nested(HooksSchema, allow_none=True)
-    flower = fields.Nested(ServiceSchema, allow_none=True)
+    flower = fields.Nested(DeploymentServiceSchema, allow_none=True)
     postgresql = fields.Nested(PostgresqlSchema, allow_none=True)
     redis = fields.Nested(RedisSchema, allow_none=True)
     rabbitmq = fields.Nested(RabbitmqSchema, data_key="rabbitmq-ha", allow_none=True)
@@ -255,10 +267,6 @@ class DeploymentSchema(BaseCamelSchema):
     intervals = fields.Nested(IntervalsSchema, allow_none=True)
     artifacts_store = fields.Nested(ConnectionTypeSchema, allow_none=True)
     connections = fields.List(fields.Nested(ConnectionTypeSchema), allow_none=True)
-    notification_connections = fields.List(
-        fields.Nested(ConnectionTypeSchema),
-        allow_none=True,
-    )
     log_level = fields.Str(allow_none=True)
     security_context = fields.Nested(SecurityContextSchema, allow_none=True)
     external_services = fields.Nested(ExternalServicesSchema, allow_none=True)
@@ -355,6 +363,9 @@ class DeploymentConfig(BaseConfig):
         node_selector=None,
         tolerations=None,
         affinity=None,
+        celery_node_selector=None,
+        celery_tolerations=None,
+        celery_affinity=None,
         limit_resources=None,
         global_replicas=None,
         global_concurrency=None,
@@ -369,6 +380,10 @@ class DeploymentConfig(BaseConfig):
         operator=None,
         init=None,
         sidecar=None,
+        notifier=None,
+        cleaner=None,
+        default_scheduling=None,
+        default_image_pull_secrets=None,
         tables_hook=None,
         clean_hooks=None,
         api_hooks=None,
@@ -388,7 +403,6 @@ class DeploymentConfig(BaseConfig):
         intervals=None,
         artifacts_store=None,
         connections=None,
-        notification_connections=None,
         log_level=None,
         security_context=None,
         external_services=None,
@@ -439,6 +453,9 @@ class DeploymentConfig(BaseConfig):
         self.node_selector = node_selector
         self.tolerations = tolerations
         self.affinity = affinity
+        self.celery_node_selector = celery_node_selector
+        self.celery_tolerations = celery_tolerations
+        self.celery_affinity = celery_affinity
         self.limit_resources = limit_resources
         self.global_replicas = global_replicas
         self.global_concurrency = global_concurrency
@@ -453,6 +470,10 @@ class DeploymentConfig(BaseConfig):
         self.operator = operator
         self.init = init
         self.sidecar = sidecar
+        self.notifier = notifier
+        self.cleaner = cleaner
+        self.default_scheduling = default_scheduling
+        self.default_image_pull_secrets = default_image_pull_secrets
         self.tables_hook = tables_hook
         self.clean_hooks = clean_hooks
         self.api_hooks = api_hooks
@@ -472,7 +493,6 @@ class DeploymentConfig(BaseConfig):
         self.intervals = intervals
         self.artifacts_store = artifacts_store
         self.connections = connections
-        self.notification_connections = notification_connections
         self.log_level = log_level
         self.security_context = security_context
         self.external_services = external_services
