@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -30,7 +30,8 @@ POLYAXON_KEYS_LOG_LEVEL = "POLYAXON_LOG_LEVEL"
 POLYAXON_KEYS_K8S_NAMESPACE = "POLYAXON_K8S_NAMESPACE"
 POLYAXON_KEYS_K8S_NODE_NAME = "POLYAXON_K8S_NODE_NAME"
 POLYAXON_KEYS_K8S_POD_ID = "POLYAXON_K8S_POD_ID"
-POLYAXON_KEYS_API_HOST = "POLYAXON_API_HOST"
+POLYAXON_KEYS_PLATFORM_HOST = "POLYAXON_PLATFORM_HOST"
+POLYAXON_KEYS_HOST = "POLYAXON_HOST"
 POLYAXON_KEYS_API_VERSION = "POLYAXON_API_VERSION"
 POLYAXON_KEYS_VERIFY_SSL = "POLYAXON_VERIFY_SSL"
 POLYAXON_KEYS_SSL_CA_CERT = "POLYAXON_SSL_CA_CERT"
@@ -39,16 +40,20 @@ POLYAXON_KEYS_KEY_FILE = "POLYAXON_KEY_FILE"
 POLYAXON_KEYS_ASSERT_HOSTNAME = "POLYAXON_ASSERT_HOSTNAME"
 POLYAXON_KEYS_CONNECTION_POOL_MAXSIZE = "POLYAXON_CONNECTION_POOL_MAXSIZE"
 POLYAXON_KEYS_ARCHIVE_ROOT = "POLYAXON_ARCHIVE_ROOT"
+POLYAXON_KEYS_ARTIFACTS_ROOT = "POLYAXON_ARTIFACTS_ROOT"
 POLYAXON_KEYS_STATIC_ROOT = "POLYAXON_STATIC_ROOT"
 POLYAXON_KEYS_CONTEXT_ROOT = "POLYAXON_CONTEXT_ROOT"
+POLYAXON_KEYS_OFFLINE_ROOT = "POLYAXON_OFFLINE_ROOT"
 POLYAXON_KEYS_DISABLE_ERRORS_REPORTING = "POLYAXON_DISABLE_ERRORS_REPORTING"
 POLYAXON_KEYS_INTERVALS_COMPATIBILITY_CHECK = "POLYAXON_INTERVALS_COMPATIBILITY_CHECK"
+POLYAXON_KEYS_UPLOAD_SIZE = "POLYAXON_UPLOAD_SIZE"
 
 # Secrets
 POLYAXON_KEYS_SECRET_KEY = "POLYAXON_SECRET_KEY"  # noqa
 POLYAXON_KEYS_SECRET_INTERNAL_TOKEN = "POLYAXON_SECRET_INTERNAL_TOKEN"  # noqa
 POLYAXON_KEYS_AUTH_TOKEN = "POLYAXON_AUTH_TOKEN"
 POLYAXON_KEYS_AUTH_USERNAME = "POLYAXON_AUTH_USERNAME"
+POLYAXON_KEYS_CUSTOM_ERRORS_OPTIONS = "POLYAXON_CUSTOM_ERRORS_OPTIONS"
 
 # Containers
 POLYAXON_KEYS_AGENT_INSTANCE = "POLYAXON_AGENT_INSTANCE"
@@ -65,18 +70,27 @@ POLYAXON_KEYS_NO_OP = "POLYAXON_NO_OP"
 POLYAXON_KEYS_NO_API = "POLYAXON_NO_API"
 
 # Registry
+POLYAXON_KEYS_USE_GIT_REGISTRY = "POLYAXON_USE_GIT_REGISTRY"
 POLYAXON_KEYS_PUBLIC_REGISTRY = "POLYAXON_PUBLIC_REGISTRY"
 
 # Agent
 POLYAXON_KEYS_AGENT_SIDECAR = "POLYAXON_AGENT_SIDECAR"
 POLYAXON_KEYS_AGENT_INIT = "POLYAXON_AGENT_INIT"
+POLYAXON_KEYS_AGENT_CLEANER = "POLYAXON_AGENT_CLEANER"
+POLYAXON_KEYS_AGENT_NOTIFIER = "POLYAXON_AGENT_NOTIFIER"
+POLYAXON_KEYS_AGENT_DEFAULT_SCHEDULING = "POLYAXON_AGENT_DEFAULT_SCHEDULING"
+POLYAXON_KEYS_AGENT_DEFAULT_IMAGE_PULL_SECRETS = (
+    "POLYAXON_AGENT_DEFAULT_IMAGE_PULL_SECRETS"
+)
 POLYAXON_KEYS_AGENT_ARTIFACTS_STORE = "POLYAXON_AGENT_ARTIFACTS_STORE"
 POLYAXON_KEYS_AGENT_CONNECTIONS = "POLYAXON_AGENT_CONNECTIONS"
-POLYAXON_KEYS_AGENT_NOTIFICATION_CONNECTIONS = "POLYAXON_AGENT_NOTIFICATION_CONNECTIONS"
 POLYAXON_KEYS_SET_AGENT = "POLYAXON_SET_AGENT"
 POLYAXON_KEYS_K8S_APP_SECRET_NAME = "POLYAXON_K8S_APP_SECRET_NAME"  # noqa
 POLYAXON_KEYS_AGENT_SECRET_NAME = "POLYAXON_AGENT_SECRET_NAME"  # noqa
 POLYAXON_KEYS_AGENT_RUNS_SA = "POLYAXON_AGENT_RUNS_SA"
+POLYAXON_KEYS_AGENT_SPAWNER_REFRESH_INTERVAL = "POLYAXON_AGENT_SPAWNER_REFRESH_INTERVAL"
+POLYAXON_KEYS_AGENT_IS_REPLICA = "POLYAXON_AGENT_IS_REPLICA"
+POLYAXON_KEYS_AGENT_COMPRESSED_LOGS = "POLYAXON_AGENT_COMPRESSED_LOGS"
 
 # Connections
 POLYAXON_KEYS_COLLECT_ARTIFACTS = "POLYAXON_COLLECT_ARTIFACTS"
@@ -84,6 +98,7 @@ POLYAXON_KEYS_COLLECT_RESOURCES = "POLYAXON_COLLECT_RESOURCES"
 POLYAXON_KEYS_ARTIFACTS_STORE_NAME = "POLYAXON_ARTIFACTS_STORE_NAME"
 POLYAXON_KEYS_GIT_CREDENTIALS = "POLYAXON_GIT_CREDENTIALS"
 POLYAXON_KEYS_SSH_PATH = "POLYAXON_SSH_PATH"
+POLYAXON_KEYS_SSH_PRIVATE_KEY = "POLYAXON_SSH_PRIVATE_KEY"
 POLYAXON_KEYS_CONNECTION_CONTEXT_PATH_FORMAT = "POLYAXON_CONNECTION_CONTEXT_PATH_{}"
 POLYAXON_KEYS_CONNECTION_SCHEMA_FORMAT = "POLYAXON_CONNECTION_SCHEMA_{}"
 
@@ -94,13 +109,20 @@ POLYAXON_KEYS_DASK_ENABLED = "POLYAXON_DASK_ENABLED"
 POLYAXON_KEYS_FLINK_ENABLED = "POLYAXON_FLINK_ENABLED"
 POLYAXON_KEYS_TFJOB_ENABLED = "POLYAXON_TFJOB_ENABLED"
 POLYAXON_KEYS_PYTORCH_JOB_ENABLED = "POLYAXON_PYTORCH_JOB_ENABLED"
+POLYAXON_KEYS_MXJOB_ENABLED = "POLYAXON_MXJOB_ENABLED"
+POLYAXON_KEYS_XGBOOST_JOB_ENABLED = "POLYAXON_XGBOOST_JOB_ENABLED"
 POLYAXON_KEYS_MPIJOB_ENABLED = "POLYAXON_MPIJOB_ENABLED"
 
 # Proxies
 POLYAXON_KEYS_PROXY_NAMESPACES = "POLYAXON_PROXY_NAMESPACES"
+POLYAXON_KEYS_PROXY_GATEWAY_PORT = "POLYAXON_PROXY_GATEWAY_PORT"
+POLYAXON_KEYS_PROXY_GATEWAY_TARGET_PORT = "POLYAXON_PROXY_GATEWAY_TARGET_PORT"
+POLYAXON_KEYS_PROXY_GATEWAY_HOST = "POLYAXON_PROXY_GATEWAY_HOST"
 POLYAXON_KEYS_PROXY_STREAMS_PORT = "POLYAXON_PROXY_STREAMS_PORT"
+POLYAXON_KEYS_PROXY_STREAMS_TARGET_PORT = "POLYAXON_PROXY_STREAMS_TARGET_PORT"
 POLYAXON_KEYS_PROXY_STREAMS_HOST = "POLYAXON_PROXY_STREAMS_HOST"
 POLYAXON_KEYS_PROXY_API_PORT = "POLYAXON_PROXY_API_PORT"
+POLYAXON_KEYS_PROXY_API_TARGET_PORT = "POLYAXON_PROXY_API_TARGET_PORT"
 POLYAXON_KEYS_PROXY_API_HOST = "POLYAXON_PROXY_API_HOST"
 POLYAXON_KEYS_PROXY_API_USE_RESOLVER = "POLYAXON_PROXY_API_USE_RESOLVER"
 POLYAXON_KEYS_PROXY_SERVICES_PORT = "POLYAXON_PROXY_SERVICES_PORT"
@@ -111,8 +133,10 @@ POLYAXON_KEYS_PROXY_AUTH_ENABLED = "POLYAXON_PROXY_AUTH_ENABLED"
 POLYAXON_KEYS_PROXY_AUTH_EXTERNAL = "POLYAXON_PROXY_AUTH_EXTERNAL"
 POLYAXON_KEYS_PROXY_AUTH_USE_RESOLVER = "POLYAXON_PROXY_AUTH_USE_RESOLVER"
 POLYAXON_KEYS_UI_ADMIN_ENABLED = "POLYAXON_UI_ADMIN_ENABLED"
+POLYAXON_KEYS_UI_ASSETS_VERSION = "POLYAXON_UI_ASSETS_VERSION"
 POLYAXON_KEYS_UI_ENABLED = "POLYAXON_UI_ENABLED"
 POLYAXON_KEYS_UI_OFFLINE = "POLYAXON_UI_OFFLINE"
+POLYAXON_KEYS_UI_BASE_URL = "POLYAXON_UI_BASE_URL"
 POLYAXON_KEYS_STATIC_URL = "POLYAXON_STATIC_URL"
 POLYAXON_KEYS_DNS_USE_RESOLVER = "POLYAXON_DNS_USE_RESOLVER"
 POLYAXON_KEYS_DNS_CUSTOM_CLUSTER = "POLYAXON_DNS_CUSTOM_CLUSTER"
