@@ -94,16 +94,13 @@ class StatusColor:
 
     @classmethod
     def get_color(cls, status: str) -> str:
-        if status in [
-            V1Statuses.FAILED,
-            V1Statuses.STOPPED,
-            V1Statuses.UPSTREAM_FAILED,
-        ]:
+        if status in [V1Statuses.FAILED, V1Statuses.UPSTREAM_FAILED]:
             return cls.RED
-        if status == V1Statuses.SUCCEEDED:
+
+        if status in [V1Statuses.SUCCEEDED, V1Statuses.SKIPPED]:
             return cls.GREEN
 
-        if status == V1Statuses.SKIPPED:
+        if status == V1Statuses.STOPPED:
             return cls.GREY
 
         if LifeCycle.is_done(status):
@@ -116,6 +113,7 @@ class LifeCycle:
     """The Run LifeCycle is state machine for status transition."""
 
     WARNING_VALUES = {V1Statuses.UNSCHEDULABLE, V1Statuses.WARNING}
+    ALL_WARNING_VALUES = WARNING_VALUES | {V1Statuses.UNKNOWN}
     SAFE_STOP_VALUES = {
         V1Statuses.CREATED,
         V1Statuses.ON_SCHEDULE,
@@ -127,19 +125,15 @@ class LifeCycle:
         V1Statuses.ON_SCHEDULE,
         V1Statuses.RESUMING,
     }
-    COMPILABLE_VALUES = {
-        V1Statuses.CREATED,
-        V1Statuses.ON_SCHEDULE,
-        V1Statuses.RESUMING,
-        V1Statuses.RETRYING,
-    }
+    COMPILABLE_VALUES = PENDING_VALUES | {V1Statuses.RETRYING}
+    ALL_PENDING_VALUES = COMPILABLE_VALUES | {V1Statuses.COMPILED, V1Statuses.QUEUED}
     RUNNING_VALUES = {
         V1Statuses.SCHEDULED,
         V1Statuses.STARTING,
         V1Statuses.PROCESSING,
         V1Statuses.RUNNING,
     }
-    ON_K8S_VALUES = RUNNING_VALUES | WARNING_VALUES | {V1Statuses.UNKNOWN}
+    ON_K8S_VALUES = RUNNING_VALUES | ALL_WARNING_VALUES
     DONE_VALUES = {
         V1Statuses.FAILED,
         V1Statuses.UPSTREAM_FAILED,
@@ -264,7 +258,9 @@ class LifeCycle:
             entity.started_at = now()
             # Update wait_time
             if entity.wait_time is None:
-                entity.wait_time = (entity.started_at - entity.created_at).seconds
+                entity.wait_time = int(
+                    (entity.started_at - entity.created_at).total_seconds()
+                )
             return True
 
         return False
@@ -277,7 +273,9 @@ class LifeCycle:
                 entity.started_at = entity.created_at
             # Update duration
             if entity.duration is None:
-                entity.duration = (entity.finished_at - entity.started_at).seconds
+                entity.duration = int(
+                    (entity.finished_at - entity.started_at).total_seconds()
+                )
             return True
         return False
 
@@ -319,3 +317,13 @@ class V1StatusCondition(ConditionMixin, polyaxon_sdk.V1StatusCondition):
 
 class V1StageCondition(ConditionMixin, polyaxon_sdk.V1StageCondition):
     pass
+
+
+class V1ProjectVersionKind(polyaxon_sdk.V1ProjectVersionKind):
+    pass
+
+
+class V1ProjectFeature(V1ProjectVersionKind):
+    RUNTIME = "runtime"
+
+    allowable_values = V1ProjectVersionKind.allowable_values + [RUNTIME]
