@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,21 +17,21 @@
 import os
 
 import click
-import click_completion
 
 from polyaxon import settings
 from polyaxon.cli.admin import admin
+from polyaxon.cli.artifacts import artifacts
 from polyaxon.cli.auth import login, logout, whoami
 from polyaxon.cli.check import check
 from polyaxon.cli.completion import completion
+from polyaxon.cli.components import components
 from polyaxon.cli.config import config
 from polyaxon.cli.dashboard import dashboard
-from polyaxon.cli.hub import hub
 from polyaxon.cli.init import init
+from polyaxon.cli.models import models
 from polyaxon.cli.operations import ops
 from polyaxon.cli.port_forward import port_forward
 from polyaxon.cli.projects import project
-from polyaxon.cli.registry import registry
 from polyaxon.cli.run import run
 from polyaxon.cli.session import set_versions_config
 from polyaxon.cli.version import check_cli_version, upgrade, version
@@ -40,7 +40,6 @@ from polyaxon.utils.bool_utils import to_bool
 from polyaxon.utils.formatting import Printer
 
 DOCS_GEN = to_bool(os.environ.get("POLYAXON_DOCS_GEN", False))
-click_completion.init()
 
 
 @click.group()
@@ -71,15 +70,27 @@ def cli(context, verbose, offline):
 
       - You can initialize a project with: polyaxon init -p [project name]
 
-      - Otherwise Polyaxon will the default global path will be used for the cache.
+      - Otherwise Polyaxon will use the default global path for the cache.
 
-    You can check the version of you CLI by running:
+    You can check the version of your CLI by running:
 
       - polyaxon version
 
-    To Enable debug mode, you can use the `-v` flag:
+    You can check the version of the CLI and the server, and the compatibility matrix with:
 
-      - polyaxon -v admin
+      - polyaxon version --check
+
+    To enable the debug mode, you can use the `-v` flag:
+
+      - polyaxon -v ...
+
+    To configure your host:
+
+      - polyaxon config set --host=...
+
+    To check your current config:
+
+      - polyaxon config show
 
     Common commands:
 
@@ -89,9 +100,9 @@ def cli(context, verbose, offline):
 
       - polyaxon ops ls
 
-      - polyaxon ops get
+      - polyaxon ops logs
 
-      - polyaxon config -l
+      - polyaxon ops get
 
       - polyaxon config set ...
 
@@ -105,7 +116,7 @@ def cli(context, verbose, offline):
 
     For more information, please visit https://polyaxon.com/docs/core/cli/
 
-    Check the help available for each command listed below.
+    Check the help available for each command listed below by appending `-h`.
     """
     settings.set_cli_config()
     configure_logger(verbose)
@@ -164,25 +175,27 @@ cli.add_command(check)
 cli.add_command(init)
 cli.add_command(project)
 cli.add_command(ops)
-cli.add_command(hub)
-cli.add_command(registry)
+cli.add_command(artifacts)
+cli.add_command(components)
+cli.add_command(models)
 cli.add_command(run)
 cli.add_command(dashboard)
 cli.add_command(admin)
 cli.add_command(port_forward)
 cli.add_command(completion)
+
 if settings.CLIENT_CONFIG.is_ops:
 
-    from polyaxon.cli.components.agent import agent
-    from polyaxon.cli.components.clean_artifacts import clean_artifacts
-    from polyaxon.cli.components.clean_ops import clean_ops
-    from polyaxon.cli.components.docker import docker
-    from polyaxon.cli.components.initializer import initializer
-    from polyaxon.cli.components.notifier import notify
-    from polyaxon.cli.components.proxies import proxy
-    from polyaxon.cli.components.sidecar import sidecar
-    from polyaxon.cli.components.tuner import tuner
-    from polyaxon.cli.components.wait import wait
+    from polyaxon.cli.services.agent import agent
+    from polyaxon.cli.services.clean_artifacts import clean_artifacts
+    from polyaxon.cli.services.clean_ops import clean_ops
+    from polyaxon.cli.services.docker import docker
+    from polyaxon.cli.services.initializer import initializer
+    from polyaxon.cli.services.notifier import notify
+    from polyaxon.cli.services.proxies import proxy
+    from polyaxon.cli.services.sidecar import sidecar
+    from polyaxon.cli.services.tuner import tuner
+    from polyaxon.cli.services.wait import wait
 
     cli.add_command(agent)
     cli.add_command(clean_artifacts)
