@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,7 +13,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
+from polyaxon.operations.cleaner import (
+    get_batch_cleaner_operation,
+    get_cleaner_operation,
+)
 from polyaxon.operations.notifier import get_notifier_operation
 from polyaxon.operations.tuner import (
     get_bo_tuner,
