@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -212,7 +212,7 @@ class BaseAsyncManager:
         self._worker = None
 
     def write(self, event: Union[LoggedEventSpec, List[LoggedEventSpec]]):
-        """Enqueue the given event to be written asychronously."""
+        """Enqueue the given event to be written asynchronously."""
         with self._lock:
             if self._closed:
                 raise IOError("Writer is closed")
