@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,20 +18,20 @@ import polyaxon_sdk
 
 from marshmallow import fields, validate
 
-from polyaxon.containers.names import MAIN_JOB_CONTAINER
-from polyaxon.k8s import k8s_schemas
 from polyaxon.polyflow.early_stopping import EarlyStoppingSchema
 from polyaxon.polyflow.matrix.base import BaseSearchConfig
 from polyaxon.polyflow.matrix.kinds import V1MatrixKind
 from polyaxon.polyflow.matrix.params import HpParamSchema
+from polyaxon.polyflow.matrix.tuner import TunerSchema
+from polyaxon.polyflow.optimization import OptimizationMetricSchema
 from polyaxon.schemas.base import BaseCamelSchema
 from polyaxon.schemas.fields.ref_or_obj import RefOrObject
-from polyaxon.schemas.fields.swagger import SwaggerField
 
 
 class HyperoptSchema(BaseCamelSchema):
     kind = fields.Str(allow_none=True, validate=validate.Equal(V1MatrixKind.HYPEROPT))
     max_iterations = RefOrObject(fields.Int(allow_none=True))
+    metric = fields.Nested(OptimizationMetricSchema, required=True)
     algorithm = fields.Str(
         allow_none=True, validate=validate.OneOf(["tpe", "rand", "anneal"])
     )
@@ -42,13 +42,9 @@ class HyperoptSchema(BaseCamelSchema):
         fields.Int(required=True, validate=validate.Range(min=1)), required=True
     )
     seed = RefOrObject(fields.Int(allow_none=True))
-    concurrency = fields.Int(allow_none=True)
-    container = SwaggerField(
-        cls=k8s_schemas.V1Container,
-        defaults={"name": MAIN_JOB_CONTAINER},
-        allow_none=True,
-    )
-    early_stopping = fields.Nested(EarlyStoppingSchema, many=True, allow_none=True)
+    concurrency = RefOrObject(fields.Int(allow_none=True))
+    tuner = fields.Nested(TunerSchema, allow_none=True)
+    early_stopping = fields.List(fields.Nested(EarlyStoppingSchema), allow_none=True)
 
     @staticmethod
     def schema_config():
@@ -65,12 +61,13 @@ class V1Hyperopt(BaseSearchConfig, polyaxon_sdk.V1Hyperopt):
     Args:
         kind: hyperopt
         algorithm: str, one of tpe, rand, anneal
-        params: List[Dict[str,
-        [params](/docs/automation/optimization-engine/params/#discrete-values)]]
-        maxIterations: int, optional
+        params: List[Dict[str, [params](/docs/automation/optimization-engine/params/#discrete-values)]]  # noqa
+        metric: V1OptimizationMetric
+        max_iterations: int, optional
         concurrency: int, optional
         num_runs: int, optional
         seed: int, optional
+        tuner: [V1Tuner](/docs/automation/optimization-engine/tuner/), optional
         early_stopping: List[[EarlyStopping](/docs/automation/helpers/early-stopping)], optional
 
 
@@ -81,10 +78,12 @@ class V1Hyperopt(BaseSearchConfig, polyaxon_sdk.V1Hyperopt):
     >>>   kind: hyperopt
     >>>   algorithm:
     >>>   maxIterations:
+    >>>   metric:
     >>>   concurrency:
     >>>   params:
     >>>   numRuns:
     >>>   seed:
+    >>>   tuner:
     >>>   earlyStopping:
     ```
 
@@ -99,6 +98,7 @@ class V1Hyperopt(BaseSearchConfig, polyaxon_sdk.V1Hyperopt):
     >>>   num_runs=20,
     >>>   concurrency=2,
     >>>   seed=23,
+    >>>   metric=V1OptimizationMetric(name="loss", optimization=V1Optimization.MINIMIZE),
     >>>   params={"param1": V1HpLogSpace(...), "param2": V1HpUniform(...), ... },
     >>>   early_stopping=[V1FailureEarlyStopping(...), V1MetricEarlyStopping(...)]
     >>> )
@@ -155,8 +155,8 @@ class V1Hyperopt(BaseSearchConfig, polyaxon_sdk.V1Hyperopt):
     [params generators](/docs/automation/optimization-engine/params/).
 
     > The parameters generated will be validated against
-    the component's inputs/outputs definition to check that the values
-    can be passed and have valid types.
+    > the component's inputs/outputs definition to check that the values
+    > can be passed and have valid types.
 
     ```yaml
     >>> matrix:
@@ -190,6 +190,19 @@ class V1Hyperopt(BaseSearchConfig, polyaxon_sdk.V1Hyperopt):
     >>>   maxIterations: 5
     ```
 
+    ### metric
+
+    The metric to optimize during the iterations,
+    this is the metric that you want to maximize or minimize.
+
+    ```yaml
+    >>> matrix:
+    >>>   kind: hyperopt
+    >>>   metric:
+    >>>     name: loss
+    >>>     optimization: minimize
+    ```
+
     ### seed
 
     Since this algorithm uses random generators,
@@ -214,26 +227,30 @@ class V1Hyperopt(BaseSearchConfig, polyaxon_sdk.V1Hyperopt):
     >>>   earlyStopping: ...
     ```
 
-    ### container
+    ### tuner
 
-    The container with the logic for creating new suggestions based on bayesian optimization,
-    users can override this section to provide different resources requirements for the tuner.
+    The tuner reference (w/o component hub reference) to use.
+    The component contains the logic for creating new suggestions based on hyperopt library,
+    users can override this section to provide a different tuner component.
 
     ```yaml
     >>> matrix:
     >>>   kind: hyperopt
-    >>>   container: ...
+    >>>   tuner:
+    >>>     hubRef: 'acme/my-hyperopt-tuner:version'
     ```
     """
 
     SCHEMA = HyperoptSchema
     IDENTIFIER = V1MatrixKind.HYPEROPT
     REDUCED_ATTRIBUTES = [
+        "maxIterations",
+        "algorithm",
         "numRuns",
         "seed",
         "concurrency",
         "earlyStopping",
-        "container",
+        "tuner",
     ]
 
     def create_iteration(self, iteration: int = None) -> int:
