@@ -19,9 +19,12 @@ import polyaxon_sdk
 from marshmallow import fields, validate
 
 from polyaxon.k8s.k8s_schemas import V1Container
+from polyaxon.polyflow.run.base import BaseRun
 from polyaxon.polyflow.run.kinds import V1RunKind
 from polyaxon.polyflow.run.kubeflow.clean_pod_policy import V1CleanPodPolicy
 from polyaxon.polyflow.run.kubeflow.replica import KFReplicaSchema
+from polyaxon.polyflow.run.kubeflow.scheduling_policy import SchedulingPolicySchema
+from polyaxon.polyflow.run.resources import V1RunResources
 from polyaxon.polyflow.run.utils import DestinationImageMixin
 from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
 
@@ -31,6 +34,7 @@ class PytorchJobSchema(BaseCamelSchema):
     clean_pod_policy = fields.Str(
         allow_none=True, validate=validate.OneOf(V1CleanPodPolicy.allowable_values)
     )
+    scheduling_policy = fields.Nested(SchedulingPolicySchema, allow_none=True)
     master = fields.Nested(KFReplicaSchema, allow_none=True)
     worker = fields.Nested(KFReplicaSchema, allow_none=True)
 
@@ -39,12 +43,15 @@ class PytorchJobSchema(BaseCamelSchema):
         return V1PytorchJob
 
 
-class V1PytorchJob(BaseConfig, DestinationImageMixin, polyaxon_sdk.V1PytorchJob):
+class V1PytorchJob(
+    BaseConfig, BaseRun, DestinationImageMixin, polyaxon_sdk.V1PytorchJob
+):
     """Kubeflow Pytorch-Job provides an interface to train distributed experiments with Pytorch.
 
     Args:
         kind: str, should be equal `pytorchjob`
         clean_pod_policy: str, one of [`All`, `Running`, `None`]
+        scheduling_policy: [V1SchedulingPolicy](/docs/experimentation/distributed/scheduling-policy/), optional  # noqa
         master: [V1KFReplica](/docs/experimentation/distributed/kubeflow-replica/), optional
         worker: [V1KFReplica](/docs/experimentation/distributed/kubeflow-replica/), optional
 
@@ -54,6 +61,7 @@ class V1PytorchJob(BaseConfig, DestinationImageMixin, polyaxon_sdk.V1PytorchJob)
     >>> run:
     >>>   kind: pytorchjob
     >>>   cleanPodPolicy:
+    >>>   schedulingPolicy:
     >>>   master:
     >>>   worker:
     ```
@@ -98,6 +106,20 @@ class V1PytorchJob(BaseConfig, DestinationImageMixin, polyaxon_sdk.V1PytorchJob)
     >>>  ...
     ```
 
+    ### schedulingPolicy
+
+    SchedulingPolicy encapsulates various scheduling policies of the distributed training
+    job, for example `minAvailable` for gang-scheduling.
+
+
+    ```yaml
+    >>> run:
+    >>>   kind: pytorchjob
+    >>>   schedulingPolicy:
+    >>>     ...
+    >>>  ...
+    ```
+
     ### master
 
     The master replica in the distributed PytorchJob
@@ -129,7 +151,7 @@ class V1PytorchJob(BaseConfig, DestinationImageMixin, polyaxon_sdk.V1PytorchJob)
 
     SCHEMA = PytorchJobSchema
     IDENTIFIER = V1RunKind.PYTORCHJOB
-    REDUCED_ATTRIBUTES = ["cleanPodPolicy", "master", "worker"]
+    REDUCED_ATTRIBUTES = ["cleanPodPolicy", "schedulingPolicy", "master", "worker"]
 
     def apply_image_destination(self, image: str):
         if self.master:
@@ -138,3 +160,35 @@ class V1PytorchJob(BaseConfig, DestinationImageMixin, polyaxon_sdk.V1PytorchJob)
         if self.worker:
             self.worker.container = self.worker.container or V1Container()
             self.worker.container.image = image
+
+    def get_resources(self):
+        resources = V1RunResources()
+        if self.master:
+            resources += self.master.get_resources()
+        if self.worker:
+            resources += self.worker.get_resources()
+        return resources
+
+    def get_all_containers(self):
+        containers = []
+        if self.master:
+            containers += self.master.get_all_containers()
+        if self.worker:
+            containers += self.worker.get_all_containers()
+        return containers
+
+    def get_all_connections(self):
+        connections = []
+        if self.master:
+            connections += self.master.get_all_connections()
+        if self.worker:
+            connections += self.worker.get_all_connections()
+        return connections
+
+    def get_all_init(self):
+        init = []
+        if self.master:
+            init += self.master.get_all_init()
+        if self.worker:
+            init += self.worker.get_all_init()
+        return init
