@@ -263,6 +263,7 @@ class BaseConverter(ConverterAbstract):
         contexts: PluginsContextsSpec,
         artifacts_store: V1ConnectionType,
         sidecar_containers: List[k8s_schemas.V1Container],
+        log_level: str = None,
     ) -> List[k8s_schemas.V1Container]:
         sidecar_containers = [
             ensure_container_name(container=c, prefix=SIDECAR_PREFIX)
@@ -277,6 +278,7 @@ class BaseConverter(ConverterAbstract):
             artifacts_store=artifacts_store,
             contexts=contexts,
             run_path=self.run_path,
+            log_level=log_level,
         )
         containers = to_list(polyaxon_sidecar_container, check_none=True)
         containers += sidecar_containers
@@ -500,6 +502,7 @@ class BaseConverter(ConverterAbstract):
         connection_by_names: Dict[str, V1ConnectionType],
         secrets: Optional[Iterable[V1K8sResourceType]],
         config_maps: Optional[Iterable[V1K8sResourceType]],
+        kv_env_vars: List[List],
         default_sa: str = None,
         ports: List[int] = None,
         num_replicas: int = None,
@@ -555,6 +558,7 @@ class BaseConverter(ConverterAbstract):
             secrets=secrets,
             config_maps=config_maps,
             ports=ports,
+            kv_env_vars=kv_env_vars,
         )
 
         labels = self.get_labels(version=pkg.VERSION, labels=environment.labels)
