@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,7 +15,11 @@
 # limitations under the License.
 
 from polyaxon.polypod.compiler.converters.kubeflow.mpi_job import MPIJobConverter
+from polyaxon.polypod.compiler.converters.kubeflow.mx_job import MXJobConverter
 from polyaxon.polypod.compiler.converters.kubeflow.pytroch_job import (
     PytorchJobConverter,
 )
 from polyaxon.polypod.compiler.converters.kubeflow.tf_job import TfJobConverter
+from polyaxon.polypod.compiler.converters.kubeflow.xgboost_job import (
+    XGBoostJobConverter,
+)
