@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,10 +17,14 @@
 import copy
 import numpy as np
 
+from datetime import date, datetime
+
 from marshmallow import ValidationError
 
 from polyaxon.polyflow import (
     V1HpChoice,
+    V1HpDateRange,
+    V1HpDateTimeRange,
     V1HpGeomSpace,
     V1HpLinSpace,
     V1HpLogNormal,
@@ -35,7 +39,7 @@ from polyaxon.polyflow import (
     V1HpRange,
     V1HpUniform,
 )
-from polyaxon.polyflow.parallel.matrix import pchoice
+from polyaxon.polyflow.matrix.params import pchoice
 from polyaxon.polytune.matrix import dist
 
 
@@ -49,6 +53,13 @@ def space_sample(value, size, rand_generator):
         return value[idx]
 
 
+def space_get_index(array, value):
+    try:
+        return array.index(value)
+    except (ValueError, AttributeError):
+        return int(np.where(array == value)[0][0])
+
+
 def dist_sample(fct, value, size, rand_generator):
     size = None if size == 1 else size
     rand_generator = rand_generator or np.random
@@ -61,9 +72,16 @@ def dist_sample(fct, value, size, rand_generator):
 def get_length(matrix):
     if matrix.IDENTIFIER == V1HpChoice.IDENTIFIER:
         return len(matrix.value)
+
     if matrix.IDENTIFIER == V1HpPChoice.IDENTIFIER:
         return len(matrix.value)
 
+    if matrix.IDENTIFIER == V1HpDateRange.IDENTIFIER:
+        return len(np.arange(**matrix.value))
+
+    if matrix.IDENTIFIER == V1HpDateTimeRange.IDENTIFIER:
+        return len(np.arange(**matrix.value))
+
     if matrix.IDENTIFIER == V1HpRange.IDENTIFIER:
         return len(np.arange(**matrix.value))
 
@@ -99,6 +117,8 @@ def get_min(matrix):
         return None
 
     if matrix.IDENTIFIER in {
+        V1HpDateRange.IDENTIFIER,
+        V1HpDateTimeRange.IDENTIFIER,
         V1HpRange.IDENTIFIER,
         V1HpLinSpace.IDENTIFIER,
         V1HpLogSpace.IDENTIFIER,
@@ -131,6 +151,8 @@ def get_max(matrix):
         return None
 
     if matrix.IDENTIFIER in {
+        V1HpDateRange.IDENTIFIER,
+        V1HpDateTimeRange.IDENTIFIER,
         V1HpRange.IDENTIFIER,
         V1HpLinSpace.IDENTIFIER,
         V1HpLogSpace.IDENTIFIER,
@@ -156,12 +178,19 @@ def get_max(matrix):
 def to_numpy(matrix):
     if matrix.IDENTIFIER == V1HpChoice.IDENTIFIER:
         return matrix.value
+
     if matrix.IDENTIFIER == V1HpPChoice.IDENTIFIER:
         raise ValidationError(
             "Distribution should not call `to_numpy`, "
             "instead it should call `sample`."
         )
 
+    if matrix.IDENTIFIER == V1HpDateRange.IDENTIFIER:
+        return np.arange(**matrix.value).astype(date)
+
+    if matrix.IDENTIFIER == V1HpDateTimeRange.IDENTIFIER:
+        return np.arange(**matrix.value).astype(datetime)
+
     if matrix.IDENTIFIER == V1HpRange.IDENTIFIER:
         return np.arange(**matrix.value)
 
@@ -200,6 +229,16 @@ def sample(matrix, size=None, rand_generator=None):
     if matrix.IDENTIFIER == V1HpPChoice.IDENTIFIER:
         return pchoice(values=matrix.value, size=size, rand_generator=rand_generator)
 
+    if matrix.IDENTIFIER == V1HpDateRange.IDENTIFIER:
+        return space_sample(
+            value=to_numpy(matrix), size=size, rand_generator=rand_generator
+        )
+
+    if matrix.IDENTIFIER == V1HpDateTimeRange.IDENTIFIER:
+        return space_sample(
+            value=to_numpy(matrix), size=size, rand_generator=rand_generator
+        )
+
     if matrix.IDENTIFIER == V1HpRange.IDENTIFIER:
         return space_sample(
             value=to_numpy(matrix), size=size, rand_generator=rand_generator
