@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,9 +21,10 @@ from polyaxon.pql.builder import QueryCondSpec
 from polyaxon.pql.parser import parse_field, tokenize_query
 
 
-class PQLManager(object):
+class PQLManager:
     NAME = None
     FIELDS_USE_UUID = None
+    FIELDS_USE_NAME = None
     FIELDS_PROXY = {}
     FIELDS_TRANS = {}
     FIELDS_ORDERING = None
@@ -42,6 +43,12 @@ class PQLManager(object):
             field = cls.FIELDS_PROXY[field]
         if cls.FIELDS_USE_UUID and not suffix and field in cls.FIELDS_USE_UUID:
             suffix = "uuid"
+        if cls.FIELDS_USE_UUID and field in cls.FIELDS_USE_UUID and suffix == "id":
+            suffix = "uuid"
+        if cls.FIELDS_USE_NAME and not suffix and field in cls.FIELDS_USE_NAME:
+            suffix = "name"
+        if cls.FIELDS_USE_NAME and field in cls.FIELDS_USE_NAME and suffix == "id":
+            suffix = "name"
         return "{}__{}".format(field, suffix) if suffix else field
 
     @classmethod
@@ -76,7 +83,7 @@ class PQLManager(object):
                 or field not in cls.CONDITIONS_BY_FIELD
             ):
                 raise PQLException(
-                    "key `{}` is not supported by query manager `{}`.".format(
+                    "key `{}` is not supported by the query manager `{}`.".format(
                         key, cls.NAME
                     )
                 )
@@ -123,13 +130,18 @@ class PQLManager(object):
         for key, cond_specs in built_query.items():
             key = cls.proxy_field(key)
             for cond_spec in cond_specs:
-                operators.append(
-                    cond_spec.cond.apply_operator(
+                try:
+                    operator = cond_spec.cond.apply_operator(
                         name=key,
                         params=cond_spec.params,
                         query_backend=cls.QUERY_BACKEND,
                         timezone=cls.TIMEZONE,
                     )
-                )
+                except Exception as e:
+                    raise PQLException(
+                        "Error applying operator for key `%s` by the query manager `%s`. "
+                        "%s" % (key, cls.NAME, e)
+                    )
+                operators.append(operator)
 
         return queryset.filter(*operators)
