@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,18 +18,30 @@ from typing import List
 from marshmallow import EXCLUDE, ValidationError, fields, pre_load, validates_schema
 
 from polyaxon.auxiliaries import (
+    PolyaxonCleanerSchema,
     PolyaxonInitContainerSchema,
+    PolyaxonNotifierSchema,
     PolyaxonSidecarContainerSchema,
 )
+from polyaxon.auxiliaries.default_scheduling import (
+    DefaultSchedulingSchema,
+    V1DefaultScheduling,
+)
 from polyaxon.containers.contexts import CONTEXT_ARTIFACTS_ROOT
 from polyaxon.env_vars.keys import (
     POLYAXON_KEYS_AGENT_ARTIFACTS_STORE,
+    POLYAXON_KEYS_AGENT_CLEANER,
+    POLYAXON_KEYS_AGENT_COMPRESSED_LOGS,
     POLYAXON_KEYS_AGENT_CONNECTIONS,
+    POLYAXON_KEYS_AGENT_DEFAULT_IMAGE_PULL_SECRETS,
+    POLYAXON_KEYS_AGENT_DEFAULT_SCHEDULING,
     POLYAXON_KEYS_AGENT_INIT,
-    POLYAXON_KEYS_AGENT_NOTIFICATION_CONNECTIONS,
+    POLYAXON_KEYS_AGENT_IS_REPLICA,
+    POLYAXON_KEYS_AGENT_NOTIFIER,
     POLYAXON_KEYS_AGENT_RUNS_SA,
     POLYAXON_KEYS_AGENT_SECRET_NAME,
     POLYAXON_KEYS_AGENT_SIDECAR,
+    POLYAXON_KEYS_AGENT_SPAWNER_REFRESH_INTERVAL,
     POLYAXON_KEYS_K8S_APP_SECRET_NAME,
     POLYAXON_KEYS_K8S_NAMESPACE,
 )
@@ -37,6 +49,7 @@ from polyaxon.exceptions import PolyaxonSchemaError
 from polyaxon.parser import parser
 from polyaxon.schemas.base import BaseConfig, BaseSchema
 from polyaxon.schemas.types import ConnectionTypeSchema, V1K8sResourceType
+from polyaxon.utils.signal_decorators import check_partial
 
 
 def validate_agent_config(artifacts_store, connections):
@@ -61,6 +74,10 @@ def validate_agent_config(artifacts_store, connections):
 
 class AgentSchema(BaseSchema):
     namespace = fields.Str(allow_none=True, data_key=POLYAXON_KEYS_K8S_NAMESPACE)
+    is_replica = fields.Bool(allow_none=True, data_key=POLYAXON_KEYS_AGENT_IS_REPLICA)
+    compressed_logs = fields.Bool(
+        allow_none=True, data_key=POLYAXON_KEYS_AGENT_COMPRESSED_LOGS
+    )
     sidecar = fields.Nested(
         PolyaxonSidecarContainerSchema,
         allow_none=True,
@@ -69,6 +86,22 @@ class AgentSchema(BaseSchema):
     init = fields.Nested(
         PolyaxonInitContainerSchema, allow_none=True, data_key=POLYAXON_KEYS_AGENT_INIT
     )
+    notifier = fields.Nested(
+        PolyaxonNotifierSchema, allow_none=True, data_key=POLYAXON_KEYS_AGENT_NOTIFIER
+    )
+    cleaner = fields.Nested(
+        PolyaxonCleanerSchema, allow_none=True, data_key=POLYAXON_KEYS_AGENT_CLEANER
+    )
+    default_scheduling = fields.Nested(
+        DefaultSchedulingSchema,
+        allow_none=True,
+        data_key=POLYAXON_KEYS_AGENT_DEFAULT_SCHEDULING,
+    )
+    default_image_pull_secrets = fields.List(
+        fields.Str(),
+        allow_none=True,
+        data_key=POLYAXON_KEYS_AGENT_DEFAULT_IMAGE_PULL_SECRETS,
+    )
     artifacts_store = fields.Nested(
         ConnectionTypeSchema,
         allow_none=True,
@@ -79,24 +112,30 @@ class AgentSchema(BaseSchema):
         allow_none=True,
         data_key=POLYAXON_KEYS_AGENT_CONNECTIONS,
     )
-    notification_connections = fields.List(
-        fields.Nested(ConnectionTypeSchema),
-        allow_none=True,
-        data_key=POLYAXON_KEYS_AGENT_NOTIFICATION_CONNECTIONS,
-    )
     app_secret_name = fields.Str(
-        allow_none=True, data_key=POLYAXON_KEYS_K8S_APP_SECRET_NAME,
+        allow_none=True,
+        data_key=POLYAXON_KEYS_K8S_APP_SECRET_NAME,
     )
     agent_secret_name = fields.Str(
-        allow_none=True, data_key=POLYAXON_KEYS_AGENT_SECRET_NAME,
+        allow_none=True,
+        data_key=POLYAXON_KEYS_AGENT_SECRET_NAME,
+    )
+    runs_sa = fields.Str(
+        allow_none=True,
+        data_key=POLYAXON_KEYS_AGENT_RUNS_SA,
+    )
+    # This refresh logic will mitigate several issues with AKS's numerous networking problems
+    spawner_refresh_interval = fields.Integer(
+        allow_none=True,
+        data_key=POLYAXON_KEYS_AGENT_SPAWNER_REFRESH_INTERVAL,
     )
-    runs_sa = fields.Str(allow_none=True, data_key=POLYAXON_KEYS_AGENT_RUNS_SA,)
 
     @staticmethod
     def schema_config():
         return AgentConfig
 
     @validates_schema
+    @check_partial
     def validate_connection(self, data, **kwargs):
         validate_agent_config(data.get("artifacts_store"), data.get("connections"))
 
@@ -115,23 +154,6 @@ class AgentSchema(BaseSchema):
         if connections:
             data[POLYAXON_KEYS_AGENT_CONNECTIONS] = connections
 
-        notification_connections = data.get(
-            POLYAXON_KEYS_AGENT_NOTIFICATION_CONNECTIONS
-        )
-        try:
-            notification_connections = parser.get_dict(
-                key=POLYAXON_KEYS_AGENT_NOTIFICATION_CONNECTIONS,
-                value=notification_connections,
-                is_list=True,
-                is_optional=True,
-            )
-        except PolyaxonSchemaError as e:
-            raise ValidationError("Received an invalid notification connections") from e
-        if notification_connections:
-            data[
-                POLYAXON_KEYS_AGENT_NOTIFICATION_CONNECTIONS
-            ] = notification_connections
-
         artifacts_store = data.get(POLYAXON_KEYS_AGENT_ARTIFACTS_STORE)
         try:
             artifacts_store = parser.get_dict(
@@ -168,6 +190,65 @@ class AgentSchema(BaseSchema):
         if init:
             data[POLYAXON_KEYS_AGENT_INIT] = init
 
+        cleaner = data.get(POLYAXON_KEYS_AGENT_CLEANER)
+        try:
+            cleaner = parser.get_dict(
+                key=POLYAXON_KEYS_AGENT_CLEANER, value=cleaner, is_optional=True
+            )
+        except PolyaxonSchemaError as e:
+            raise ValidationError(
+                "Received an invalid cleaner `{}`".format(cleaner)
+            ) from e
+        if cleaner:
+            data[POLYAXON_KEYS_AGENT_CLEANER] = cleaner
+
+        notifier = data.get(POLYAXON_KEYS_AGENT_NOTIFIER)
+        try:
+            notifier = parser.get_dict(
+                key=POLYAXON_KEYS_AGENT_NOTIFIER, value=notifier, is_optional=True
+            )
+        except PolyaxonSchemaError as e:
+            raise ValidationError(
+                "Received an invalid notifier `{}`".format(notifier)
+            ) from e
+        if notifier:
+            data[POLYAXON_KEYS_AGENT_NOTIFIER] = notifier
+
+        default_scheduling = data.get(POLYAXON_KEYS_AGENT_DEFAULT_SCHEDULING)
+        try:
+            default_scheduling = parser.get_dict(
+                key=POLYAXON_KEYS_AGENT_DEFAULT_SCHEDULING,
+                value=default_scheduling,
+                is_optional=True,
+            )
+        except PolyaxonSchemaError as e:
+            raise ValidationError(
+                "Received an invalid default_scheduling `{}`".format(default_scheduling)
+            ) from e
+        if default_scheduling:
+            data[POLYAXON_KEYS_AGENT_DEFAULT_SCHEDULING] = default_scheduling
+
+        default_image_pull_secrets = data.get(
+            POLYAXON_KEYS_AGENT_DEFAULT_IMAGE_PULL_SECRETS
+        )
+        try:
+            default_image_pull_secrets = parser.get_string(
+                key=POLYAXON_KEYS_AGENT_DEFAULT_IMAGE_PULL_SECRETS,
+                value=default_image_pull_secrets,
+                is_optional=True,
+                is_list=True,
+            )
+        except PolyaxonSchemaError as e:
+            raise ValidationError(
+                "Received an invalid default_image_pull_secrets `{}`".format(
+                    default_image_pull_secrets
+                )
+            ) from e
+        if default_image_pull_secrets:
+            data[
+                POLYAXON_KEYS_AGENT_DEFAULT_IMAGE_PULL_SECRETS
+            ] = default_image_pull_secrets
+
         return data
 
 
@@ -178,43 +259,72 @@ class AgentConfig(BaseConfig):
     REDUCED_ATTRIBUTES = [
         POLYAXON_KEYS_AGENT_SIDECAR,
         POLYAXON_KEYS_AGENT_INIT,
+        POLYAXON_KEYS_AGENT_NOTIFIER,
+        POLYAXON_KEYS_AGENT_CLEANER,
+        POLYAXON_KEYS_AGENT_IS_REPLICA,
+        POLYAXON_KEYS_AGENT_COMPRESSED_LOGS,
         POLYAXON_KEYS_AGENT_ARTIFACTS_STORE,
         POLYAXON_KEYS_AGENT_CONNECTIONS,
-        POLYAXON_KEYS_AGENT_NOTIFICATION_CONNECTIONS,
         POLYAXON_KEYS_K8S_APP_SECRET_NAME,
         POLYAXON_KEYS_AGENT_SECRET_NAME,
         POLYAXON_KEYS_AGENT_RUNS_SA,
+        POLYAXON_KEYS_AGENT_SPAWNER_REFRESH_INTERVAL,
+        POLYAXON_KEYS_AGENT_DEFAULT_SCHEDULING,
+        POLYAXON_KEYS_AGENT_DEFAULT_IMAGE_PULL_SECRETS,
     ]
 
     def __init__(
         self,
         namespace=None,
+        is_replica=None,
+        compressed_logs=None,
         sidecar=None,
         init=None,
+        notifier=None,
+        cleaner=None,
         artifacts_store=None,
         connections=None,
-        notification_connections=None,
         app_secret_name=None,
         agent_secret_name=None,
         runs_sa=None,
+        spawner_refresh_interval=None,
+        default_scheduling=None,
+        default_image_pull_secrets=None,
         **kwargs
     ):
         self.namespace = namespace
+        self.is_replica = is_replica
+        self.compressed_logs = compressed_logs
         self.sidecar = sidecar
         self.init = init
+        self.notifier = notifier
+        self.cleaner = cleaner
         self.artifacts_store = artifacts_store
         self.connections = connections or []
-        self.notification_connections = notification_connections or []
         self.app_secret_name = app_secret_name
         self.agent_secret_name = agent_secret_name
         self.runs_sa = runs_sa
-        self._all_connections = self.connections[:]
-        if artifacts_store:
-            self._all_connections.append(artifacts_store)
+        self.spawner_refresh_interval = spawner_refresh_interval
+        self.default_image_pull_secrets = default_image_pull_secrets
+        self.default_scheduling = default_scheduling
+        if not self.default_scheduling and self.default_image_pull_secrets:
+            self.default_scheduling = V1DefaultScheduling()
+        if self.default_scheduling and not self.default_scheduling.image_pull_secrets:
+            self.default_scheduling.image_pull_secrets = self.default_image_pull_secrets
+        self._all_connections = []
+        self.set_all_connections()
         self._secrets = None
         self._config_maps = None
         self._connections_by_names = {}
-        self._notification_connections_by_names = {}
+
+    def get_spawner_refresh_interval(self):
+        return self.spawner_refresh_interval or 60 * 5
+
+    def set_all_connections(self):
+        self._all_connections = self.connections[:]
+        if self.artifacts_store:
+            self._all_connections.append(self.artifacts_store)
+            validate_agent_config(self.artifacts_store, self.connections)
 
     @property
     def all_connections(self):
@@ -254,16 +364,6 @@ class AgentConfig(BaseConfig):
         self._connections_by_names = {c.name: c for c in self._all_connections}
         return self._connections_by_names
 
-    @property
-    def notification_connections_by_names(self):
-        if self._notification_connections_by_names:
-            return self._notification_connections_by_names
-
-        self._notification_connections_by_names = {
-            c.name: c for c in self.notification_connections
-        }
-        return self._notification_connections_by_names
-
     @property
     def artifacts_root(self):
         artifacts_root = CONTEXT_ARTIFACTS_ROOT
