@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,7 +21,6 @@ from marshmallow import EXCLUDE, fields
 from polyaxon.api import get_default_host
 from polyaxon.containers.contexts import CONTEXT_ARCHIVE_ROOT
 from polyaxon.env_vars.keys import (
-    POLYAXON_KEYS_API_HOST,
     POLYAXON_KEYS_API_VERSION,
     POLYAXON_KEYS_ARCHIVE_ROOT,
     POLYAXON_KEYS_ASSERT_HOSTNAME,
@@ -32,6 +31,7 @@ from polyaxon.env_vars.keys import (
     POLYAXON_KEYS_DISABLE_ERRORS_REPORTING,
     POLYAXON_KEYS_HEADER,
     POLYAXON_KEYS_HEADER_SERVICE,
+    POLYAXON_KEYS_HOST,
     POLYAXON_KEYS_INTERVAL,
     POLYAXON_KEYS_INTERVALS_COMPATIBILITY_CHECK,
     POLYAXON_KEYS_IS_MANAGED,
@@ -39,7 +39,6 @@ from polyaxon.env_vars.keys import (
     POLYAXON_KEYS_IS_OPS,
     POLYAXON_KEYS_K8S_IN_CLUSTER,
     POLYAXON_KEYS_K8S_NAMESPACE,
-    POLYAXON_KEYS_K8S_POD_ID,
     POLYAXON_KEYS_KEY_FILE,
     POLYAXON_KEYS_LOG_LEVEL,
     POLYAXON_KEYS_NO_API,
@@ -62,7 +61,7 @@ from polyaxon.utils.http_utils import clean_host, clean_verify_ssl
 
 class ClientSchema(BaseSchema):
     service = fields.Str(allow_none=True, data_key=POLYAXON_KEYS_SERVICE)
-    host = fields.Str(allow_none=True, data_key=POLYAXON_KEYS_API_HOST)
+    host = fields.Str(allow_none=True, data_key=POLYAXON_KEYS_HOST)
     version = fields.Str(allow_none=True, data_key=POLYAXON_KEYS_API_VERSION)
     debug = fields.Bool(allow_none=True, data_key=POLYAXON_KEYS_DEBUG)
     log_level = fields.Str(allow_none=True, data_key=POLYAXON_KEYS_LOG_LEVEL)
@@ -78,9 +77,7 @@ class ClientSchema(BaseSchema):
     tracking_timeout = fields.Float(
         allow_none=True, data_key=POLYAXON_KEYS_TRACKING_TIMEOUT
     )
-    timezone = fields.Str(
-        allow_none=True, data_key=POLYAXON_KEYS_TIME_ZONE, default="UTC"
-    )
+    timezone = fields.Str(allow_none=True, data_key=POLYAXON_KEYS_TIME_ZONE)
     watch_interval = fields.Int(allow_none=True, data_key=POLYAXON_KEYS_WATCH_INTERVAL)
     interval = fields.Float(allow_none=True, data_key=POLYAXON_KEYS_INTERVAL)
     verify_ssl = fields.Bool(allow_none=True, data_key=POLYAXON_KEYS_VERIFY_SSL)
@@ -98,7 +95,6 @@ class ClientSchema(BaseSchema):
     header = fields.Str(allow_none=True, data_key=POLYAXON_KEYS_HEADER)
     header_service = fields.Str(allow_none=True, data_key=POLYAXON_KEYS_HEADER_SERVICE)
 
-    pod_id = fields.Str(allow_none=True, data_key=POLYAXON_KEYS_K8S_POD_ID)
     namespace = fields.Str(allow_none=True, data_key=POLYAXON_KEYS_K8S_NAMESPACE)
     no_api = fields.Bool(allow_none=True, data_key=POLYAXON_KEYS_NO_API)
     disable_errors_reporting = fields.Bool(
@@ -124,7 +120,7 @@ class ClientConfig(BaseConfig):
 
     REDUCED_ATTRIBUTES = [
         POLYAXON_KEYS_SERVICE,
-        POLYAXON_KEYS_API_HOST,
+        POLYAXON_KEYS_HOST,
         POLYAXON_KEYS_API_VERSION,
         POLYAXON_KEYS_ASSERT_HOSTNAME,
         POLYAXON_KEYS_AUTHENTICATION_TYPE,
@@ -140,7 +136,6 @@ class ClientConfig(BaseConfig):
         POLYAXON_KEYS_IS_OFFLINE,
         POLYAXON_KEYS_IS_OPS,
         POLYAXON_KEYS_K8S_NAMESPACE,
-        POLYAXON_KEYS_K8S_POD_ID,
         POLYAXON_KEYS_KEY_FILE,
         POLYAXON_KEYS_LOG_LEVEL,
         POLYAXON_KEYS_NO_API,
@@ -182,7 +177,6 @@ class ClientConfig(BaseConfig):
         archive_root=None,
         header=None,
         header_service=None,
-        pod_id=None,
         namespace=None,
         no_api=None,
         disable_errors_reporting=None,
@@ -216,7 +210,6 @@ class ClientConfig(BaseConfig):
         self.timezone = timezone
         self.interval = interval or 5
         self.watch_interval = watch_interval or 5
-        self.pod_id = pod_id
         self.namespace = namespace
         self.no_api = self._get_bool(no_api, False)
         self.authentication_type = authentication_type or AuthenticationTypes.TOKEN
@@ -265,8 +258,8 @@ class ClientConfig(BaseConfig):
         if self.connection_pool_maxsize:
             config.connection_pool_maxsize = self.connection_pool_maxsize
         if self.token:
-            config.api_key["Authorization"] = self.token
-            config.api_key_prefix["Authorization"] = self.authentication_type
+            config.api_key["ApiKey"] = self.token
+            config.api_key_prefix["ApiKey"] = self.authentication_type
         return config
 
     @staticmethod
