@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,7 +21,9 @@ from marshmallow import fields, validates_schema
 from polyaxon.schemas.base import BaseCamelSchema
 from polyaxon.schemas.fields.docker_image import validate_image
 from polyaxon.schemas.fields.ref_or_obj import RefOrObject
+from polyaxon.schemas.fields.str_or_list import StrOrList
 from polyaxon.schemas.types.base import BaseTypeConfig
+from polyaxon.utils.signal_decorators import check_partial
 
 POLYAXON_DOCKERFILE_NAME = "Dockerfile"
 POLYAXON_DOCKER_WORKDIR = "/code"
@@ -32,11 +34,13 @@ class DockerfileTypeSchema(BaseCamelSchema):
     image = RefOrObject(fields.Str(), required=True)
     env = RefOrObject(fields.Dict(keys=fields.Str(), allow_none=True))
     path = RefOrObject(fields.List(fields.Str(), allow_none=True))
-    copy = RefOrObject(fields.List(fields.Str(), allow_none=True))
+    copy = RefOrObject(fields.List(StrOrList(), allow_none=True))
+    post_run_copy = RefOrObject(fields.List(StrOrList(), allow_none=True))
     run = RefOrObject(fields.List(fields.Str(), allow_none=True))
     lang_env = RefOrObject(fields.Str(allow_none=True))
     uid = RefOrObject(fields.Int(allow_none=True))
     gid = RefOrObject(fields.Int(allow_none=True))
+    username = RefOrObject(fields.Str(allow_none=True))
     filename = RefOrObject(fields.Str(allow_none=True))
     workdir = RefOrObject(fields.Str(allow_none=True))
     workdir_path = RefOrObject(fields.Str(allow_none=True))
@@ -47,6 +51,7 @@ class DockerfileTypeSchema(BaseCamelSchema):
         return V1DockerfileType
 
     @validates_schema
+    @check_partial
     def validate_dockerfile(self, data, **kwargs):
         validate_image(data.get("image"))
 
@@ -62,11 +67,13 @@ class V1DockerfileType(BaseTypeConfig, polyaxon_sdk.V1DockerfileType):
         image: str
         env: Dict, optional
         path: List[str], optional
-        copy: List[str], optional
+        copy: Union[List[str], List[[str, str]], optional
+        post_run_copy: Union[List[str], List[[str, str]], optional
         run: List[str], optional
         lang_env: str, optional
         uid: str, optional
         gid: str, optional
+        username: str, optional, default 'polyaxon'
         filename: str, optional
         workdir: str, optional
         workdir_path: str, optional
@@ -74,6 +81,8 @@ class V1DockerfileType(BaseTypeConfig, polyaxon_sdk.V1DockerfileType):
 
     ### YAML usage
 
+    ### Usage in IO and params definition
+
     The inputs definition
 
     ```yaml
@@ -93,8 +102,26 @@ class V1DockerfileType(BaseTypeConfig, polyaxon_sdk.V1DockerfileType):
     >>>       env: {'KEY1': 'en_US.UTF-8', 'KEY2':2}
     ```
 
+    ### Usage in initializers
+
+    ```yaml
+     ```yaml
+    >>> version:  1.1
+    >>> kind: component
+    >>> run:
+    >>>   kind: job
+    >>>   init:
+    >>>   - dockerfile:
+    >>>       image: test
+    >>>       run: ["pip install package1"]
+    >>>       env: {'KEY1': 'en_US.UTF-8', 'KEY2':2}
+    >>>     ...
+    ```
+
     ### Python usage
 
+    ### Usage in IO and params definition
+
     The inputs definition
 
     ```python
@@ -104,7 +131,7 @@ class V1DockerfileType(BaseTypeConfig, polyaxon_sdk.V1DockerfileType):
     >>> inputs = [
     >>>     V1IO(
     >>>         name="test1",
-    >>>         iotype=types.DOCKERFILE,
+    >>>         type=types.DOCKERFILE,
     >>>     ),
     >>> ]
     ```
@@ -126,15 +153,45 @@ class V1DockerfileType(BaseTypeConfig, polyaxon_sdk.V1DockerfileType):
     >>> }
     ```
 
+    ### Usage in initializers
+
+    ```python
+    >>> from polyaxon.polyflow import V1Component, V1Init, V1Job
+    >>> from polyaxon.schemas.types import V1DockerfileType
+    >>> from polyaxon.k8s import k8s_schemas
+    >>> component = V1Component(
+    >>>     run=V1Job(
+    >>>        init=[
+    >>>             V1Init(
+    >>>                 dockerfile=V1DockerfileType(
+    >>>                     image="test",
+    >>>                     run=["pip install package1"],
+    >>>                     env={'KEY1': 'en_US.UTF-8', 'KEY2':2},
+    >>>                 )
+    >>>             ),
+    >>>        ],
+    >>>        container=k8s_schemas.V1Container(...)
+    >>>     )
+    >>> )
+    ```
+
     ### Fields
       * image: the base image to use, is will exposed as `FROM` command in the dockerfile.
       * env: environment variables dictionary that will be exposed as `ENV` sections.
       * path: list of paths to be added to your `PATH` environment variable.
-      * copy: a list a copy commands that will be exposed as list of COPY commands.
+      * copy: a list a copy commands that will be exposed as list of COPY commands. You can pass a
+        Union[List[str], List[[str, str]], if a str is passed it will be placed under the workdir,
+        if [str, str] is passed the path will be placed under the second string.
+      * postRunCopy: Similar to the copy section,
+        the COPY commands will be placed after RUN commands.
+        This could be very useful to leverage any cached commands before copying new artifacts.
       * run: a list a run commands that will be exposed as list of RUN commands.
       * langEnv: if passed it will expose these environment variable: ENV LC_ALL, LANG, LANGUAGE
       * uid and gid: will create a new user based on these 2 values.
+      * username: an optional name to use for the uid/gid, default is 'polyaxon' user.
       * filename: an optional name for your dockerfile, default is Dockerfile.
+        **N.B.** this is not a path, if you need to generate the dockerfile on a custom path,
+        you will need to set the path key on the init container definition.
       * workdir: the WORKDIR for your dockerfile, default is `/code`
       * workdirPath: the local workdir to copy to the docker container.
       * shell: shell type environment variable, default `/bin/bash`.
@@ -142,22 +199,26 @@ class V1DockerfileType(BaseTypeConfig, polyaxon_sdk.V1DockerfileType):
     ### Example
 
     ```yaml
-    image: image:tag
-    env:
-      KEY1: value1
-      KEY2: value2
-    path:
-    - module/add/to/path
-    copy:
-    - copy/local/path
-    run:
-    - pip install ...
-    - mv foo bar
-    langEnv: en_US.UTF-8
-    uid: 2222
-    gid: 1111
-    filename: Dockerfile2
-    workdir: ../my-code
+    >>> image: image:tag
+    >>> env:
+    >>>   KEY1: value1
+    >>>   KEY2: value2
+    >>> path:
+    >>> - module/add/to/path
+    >>> copy:
+    >>> - copy/local/requirements.txt
+    >>> - [copy/.cache/dir, /destination]
+    >>> run:
+    >>> - pip install ...
+    >>> - mv foo bar
+    >>> postRunCopy:
+    >>> - copy/local/path
+    >>> - [copy/local/path, /path/to/user/in/container]
+    >>> langEnv: en_US.UTF-8
+    >>> uid: 2222
+    >>> gid: 1111
+    >>> filename: Dockerfile2
+    >>> workdir: ../my-code
     ```
     """
 
@@ -168,10 +229,12 @@ class V1DockerfileType(BaseTypeConfig, polyaxon_sdk.V1DockerfileType):
         "env",
         "path",
         "copy",
+        "postRunCopy",
         "run",
         "langEnv",
         "uid",
         "gid",
+        "username",
         "filename",
         "workdir",
         "workdirPath",
