@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,12 +25,17 @@ from polyaxon.exceptions import PolyaxonDateTimeFormatterException
 epoch = datetime(1970, 1, 1, tzinfo=pytz.utc)
 
 
+def parse_datetime(value):
+    if isinstance(value, str):
+        return dt_parser.parse(value)
+    return value
+
+
 def to_timestamp(value):
     """
     Convert a time zone aware datetime to a POSIX timestamp (with fractional component.)
     """
-    if isinstance(value, str):
-        value = dt_parser.parse(value)
+    value = parse_datetime(value)
     return (value - epoch).total_seconds()
 
 
@@ -49,9 +54,15 @@ def path_last_modified(filepath: str) -> datetime:
 
 
 def file_modified_since(filepath: str, last_time: datetime) -> bool:
+    if not last_time:
+        return True
     return path_last_modified(filepath) > last_time
 
 
+def as_timezone(value, timezone):
+    return value.astimezone(pytz.timezone(timezone))
+
+
 class DateTimeFormatter:
     """
     The `DateTimeFormatter` class implements a utility used to create
@@ -89,7 +100,7 @@ class DateTimeFormatter:
         return timestamp.strftime(cls.DATETIME_FORMAT)
 
     @classmethod
-    def extract_date(cls, date_str, timezone):
+    def extract_date(cls, date_str, timezone, force_tz: bool = False):
         """
         Tries to extract a `datetime` object from the given string, expecting
         date information only.
@@ -107,14 +118,23 @@ class DateTimeFormatter:
             )
 
         try:
-            return cls._extract_timestamp(date_str, cls.DATE_FORMAT, timezone=timezone)
+            return cls.extract_iso_timestamp(
+                date_str, timezone=timezone, force_tz=force_tz
+            )
+        except (TypeError, ValueError, AttributeError):
+            pass
+
+        try:
+            return cls.extract_timestamp(
+                date_str, cls.DATE_FORMAT, timezone=timezone, force_tz=force_tz
+            )
         except (TypeError, ValueError):
             raise PolyaxonDateTimeFormatterException(
                 "Invalid date string {}.".format(date_str)
             )
 
     @classmethod
-    def extract_datetime(cls, datetime_str, timezone):
+    def extract_datetime(cls, datetime_str, timezone, force_tz: bool = False):
         """
         Tries to extract a `datetime` object from the given string, including
         time information.
@@ -130,8 +150,15 @@ class DateTimeFormatter:
             )
 
         try:
-            return cls._extract_timestamp(
-                datetime_str, cls.DATETIME_FORMAT, timezone=timezone
+            return cls.extract_iso_timestamp(
+                datetime_str, timezone=timezone, force_tz=force_tz
+            )
+        except (TypeError, ValueError, AttributeError):
+            pass
+
+        try:
+            return cls.extract_timestamp(
+                datetime_str, cls.DATETIME_FORMAT, timezone=timezone, force_tz=force_tz
             )
         except (TypeError, ValueError):
             raise PolyaxonDateTimeFormatterException(
@@ -139,7 +166,7 @@ class DateTimeFormatter:
             )
 
     @classmethod
-    def extract_datetime_hour(cls, datetime_str, timezone):
+    def extract_datetime_hour(cls, datetime_str, timezone, force_tz: bool = False):
         """
         Tries to extract a `datetime` object from the given string, including only hours.
 
@@ -154,8 +181,18 @@ class DateTimeFormatter:
             )
 
         try:
-            return cls._extract_timestamp(
-                datetime_str, cls.DATETIME_HOUR_FORMAT, timezone=timezone
+            return cls.extract_iso_timestamp(
+                datetime_str, timezone=timezone, force_tz=force_tz
+            )
+        except (TypeError, ValueError, AttributeError):
+            pass
+
+        try:
+            return cls.extract_timestamp(
+                datetime_str,
+                cls.DATETIME_HOUR_FORMAT,
+                timezone=timezone,
+                force_tz=force_tz,
             )
         except (TypeError, ValueError):
             raise PolyaxonDateTimeFormatterException(
@@ -198,7 +235,18 @@ class DateTimeFormatter:
         return cls.extract_date(timestamp_str, timezone=timezone)
 
     @staticmethod
-    def _extract_timestamp(timestamp_str, dt_format, timezone):
+    def extract_iso_timestamp(timestamp_str, timezone, force_tz: bool = False):
+        timestamp = datetime.fromisoformat(timestamp_str)
+        if not timestamp.tzinfo and timezone:
+            timestamp = timestamp.replace(tzinfo=pytz.timezone(timezone))
+        if force_tz:
+            timestamp = as_timezone(timestamp, timezone)
+        return timestamp
+
+    @staticmethod
+    def extract_timestamp(timestamp_str, dt_format, timezone, force_tz: bool = False):
         timestamp = datetime.strptime(timestamp_str, dt_format)
         timestamp = timestamp.replace(tzinfo=pytz.timezone(timezone))
+        if force_tz:
+            timestamp = as_timezone(timestamp, timezone)
         return timestamp
