@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,6 +16,41 @@
 
 
 def memoize(func):
+    """
+    Decorator: provide result cache for wrapped func. Results are cached
+    for given parameter list.
+
+    See also: http://en.wikipedia.org/wiki/Memoization
+
+    Example:
+
+        @memoize
+        def foo(param1, param2):
+            return do_calculation(param1, param2)
+
+        a = foo(1, 2)
+        b = foo(1, 2)
+
+        The second call is a cache hit and does not lead to a 'do_calculation'
+        call.
+
+    HINT: - The current implementation does not allow to clear the cache.
+            Therefore, the decorator should only be used in limited scope,
+            e.g. to enhance a locally defined methods.
+          - The decorator does not work with keyword arguments.
+    """
+
+    cache = {}
+
+    def wrapper(*x):
+        if x not in cache:
+            cache[x] = func(*x)
+        return cache[x]
+
+    return wrapper
+
+
+def memoize_method(func):
     """
     Provides memoization for methods on a specific instance.
     Results are cached for given parameter list.
@@ -29,7 +64,7 @@ def memoize(func):
 
     Example:
 
-        class MyClass(object):
+        class MyClass:
             @memoize
             def foo(self, a, b):
                 return self._do_calculation(a, b)
