@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2020 Polyaxon, Inc.
+# Copyright 2018-2021 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 
 import pytz
 
-from datetime import datetime
+from datetime import datetime, timedelta
 
 from dateutil.tz import tzlocal
 
@@ -29,7 +29,7 @@ except ImportError:
 def get_timezone(tz=None):
     from polyaxon import settings
 
-    tz = tz or settings.CLIENT_CONFIG.timezone or "UTC"
+    tz = tz or settings.CLIENT_CONFIG.timezone
     if tz:
         return pytz.timezone(tz)
     return tzlocal()
@@ -39,9 +39,13 @@ def now(tzinfo=True, no_micor=False):
     """
     Return an aware or naive datetime.datetime, depending on settings.USE_TZ.
     """
+    value = None
     if dj_now:
-        value = dj_now()
-    else:
+        try:
+            value = dj_now()
+        except Exception:  # Improper configuration
+            pass
+    if not value:
         if tzinfo:
             value = datetime.utcnow().replace(tzinfo=pytz.utc)
         else:
@@ -53,3 +57,7 @@ def now(tzinfo=True, no_micor=False):
 
 def local_datetime(datetime_value, tz=None):
     return datetime_value.astimezone(get_timezone(tz))
+
+
+def get_datetime_from_now(days: int, hours: int = 0, minutes: int = 0) -> datetime:
+    return now() - timedelta(days=days, hours=hours, minutes=minutes)
